"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QTextDocument(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qtextdocument.html

    **Detailed Description**

    QTextDocument is a container for structured rich text documents, providing
    support for styled text and various types of document elements, such as
    lists, tables, frames, and images. They can be created for use in a
    **QTextEdit** , or used independently.

    Each document element is described by an associated format object. Each
    format object is treated as a unique object by QTextDocuments, and can be
    passed to **objectForFormat** () to obtain the document element that it is
    applied to.

    A QTextDocument can be edited programmatically using a **QTextCursor** , and
    its contents can be examined by traversing the document structure. The
    entire document structure is stored as a hierarchy of document elements
    beneath the root frame, found with the **rootFrame** () function.
    Alternatively, if you just want to iterate over the textual contents of the
    document you can use **begin** (), **end** (), and **findBlock** () to
    retrieve text blocks that you can examine and iterate over.

    The layout of a document is determined by the **documentLayout** (); you can
    create your own **QAbstractTextDocumentLayout**  subclass and set it using
    **setDocumentLayout** () if you want to use your own layout logic. The
    document's title and other meta-information can be obtained by calling the
    **metaInformation** () function. For documents that are exposed to users
    through the **QTextEdit**  class, the document title is also available via
    the **QTextEdit::documentTitle** () function.

    The **toPlainText** () and **toHtml** () convenience functions allow you to
    retrieve the contents of the document as plain text and HTML. The document's
    text can be searched using the **find** () functions.

    Undo/redo of operations performed on the document can be controlled using
    the **setUndoRedoEnabled** () function. The undo/redo system can be
    controlled by an editor widget through the **undo** () and **redo** ()
    slots; the document also provides **contentsChanged** (), **undoAvailable**
    (), and **redoAvailable** () signals that inform connected editor widgets
    about the state of the undo/redo system. The following are the undo/redo
    operations of a QTextDocument:

    * Insertion or removal of characters. A sequence of insertions or removals
    within the same text block are regarded as a single undo/redo operation.
      *
    Insertion or removal of text blocks. Sequences of insertion or removals in a
    single operation (e.g., by selecting and then deleting text) are regarded as
    a single undo/redo operation.
      * Text character format changes.
      * Text
    block format changes.
      * Text block group format changes.

    **See also** **QTextCursor** , **QTextEdit** , **Rich Text Processing** ,
    and **Text Object Example** .
    """

    class MarkdownFeature(enum.Flag):
        MarkdownNoHTML: QTextDocument = ...
        MarkdownDialectCommonMark: QTextDocument = ...
        MarkdownDialectGitHub: QTextDocument = ...

    class Stacks(enum.Enum):
        UndoStack: QTextDocument = ...
        RedoStack: QTextDocument = ...
        UndoAndRedoStacks: QTextDocument = ...

    class ResourceType(enum.Enum):
        UnknownResource: QTextDocument = ...
        HtmlResource: QTextDocument = ...
        ImageResource: QTextDocument = ...
        StyleSheetResource: QTextDocument = ...
        MarkdownResource: QTextDocument = ...
        UserResource: QTextDocument = ...

    class FindFlag(enum.Flag):
        FindBackward: QTextDocument = ...
        FindCaseSensitively: QTextDocument = ...
        FindWholeWords: QTextDocument = ...

    class MetaInformation(enum.Enum):
        DocumentTitle: QTextDocument = ...
        DocumentUrl: QTextDocument = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#QTextDocument

        **QTextDocument::QTextDocument(QObject * parent = nullptr)**

        Constructs an empty QTextDocument with the given **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, text: str, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#QTextDocument-1

        **QTextDocument::QTextDocument(const QString & text , QObject * parent =
        nullptr)**

        Constructs a QTextDocument containing the plain (unformatted) **text**
        specified, and with the given **parent**.
        """
        ...

    @staticmethod
    def setDefaultResourceProvider(
        provider: typing.Callable[[QtCore.QUrl], typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setDefaultResourceProvider

        **[static, since 6.1] void
        QTextDocument::setDefaultResourceProvider(const
        QTextDocument::ResourceProvider & provider )**

        Sets the default resource provider to **provider**.

        The default provider will be used by all QTextDocuments that don't have
        an explicit provider set.

        This function was introduced in Qt 6.1.

        **See also** **defaultResourceProvider** (), **setResourceProvider** (),
        and **loadResource** ().
        """
        ...

    @staticmethod
    def defaultResourceProvider() -> typing.Callable[[QtCore.QUrl], typing.Any]:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#defaultResourceProvider

        **[static, since 6.1] QTextDocument::ResourceProvider
        QTextDocument::defaultResourceProvider()**

        Returns the default resource provider.

        This function was introduced in Qt 6.1.

        **See also** **setDefaultResourceProvider** (), **resourceProvider** (),
        and **loadResource** ().
        """
        ...

    def setResourceProvider(
        self, provider: typing.Callable[[QtCore.QUrl], typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setResourceProvider

        **[since 6.1] void QTextDocument::setResourceProvider(const
        QTextDocument::ResourceProvider & provider )**

        Sets the provider of resources for the text document to **provider**.

        This function was introduced in Qt 6.1.

        **See also** **resourceProvider** () and **loadResource** ().
        """
        ...

    def resourceProvider(self) -> typing.Callable[[QtCore.QUrl], typing.Any]:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#resourceProvider

        **[since 6.1] QTextDocument::ResourceProvider
        QTextDocument::resourceProvider() const**

        Returns the resource provider for this text document.

        This function was introduced in Qt 6.1.

        **See also** **setResourceProvider** (), **defaultResourceProvider** (),
        and **loadResource** ().
        """
        ...

    def baselineOffset(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#baselineOffset

        **[since 6.0] qreal QTextDocument::baselineOffset() const**

        Returns the the baseline offset in % used in the document layout.

        This function was introduced in Qt 6.0.

        **See also** **setBaselineOffset** (), **setSubScriptBaseline** (),
        **subScriptBaseline** (), **setSuperScriptBaseline** (), and
        **superScriptBaseline** ().
        """
        ...

    def setBaselineOffset(self, baseline: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setBaselineOffset

        **[since 6.0] void QTextDocument::setBaselineOffset(qreal baseline )**

        Sets the base line as a% of font height to use in the document layout to
        **baseline**. The default value is 0. A positive value moves up the
        text, by the corresponding %; a negative value moves it down.

        This function was introduced in Qt 6.0.

        **See also** **baselineOffset** (), **setSubScriptBaseline** (),
        **subScriptBaseline** (), **setSuperScriptBaseline** (), and
        **superScriptBaseline** ().
        """
        ...

    def subScriptBaseline(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#subScriptBaseline

        **[since 6.0] qreal QTextDocument::subScriptBaseline() const**

        Returns the superscript's base line as a % of font height used in the
        document layout.

        This function was introduced in Qt 6.0.

        **See also** **setSubScriptBaseline** (), **setSuperScriptBaseline** (),
        **superScriptBaseline** (), **setBaselineOffset** (), and
        **baselineOffset** ().
        """
        ...

    def setSubScriptBaseline(self, baseline: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setSubScriptBaseline

        **[since 6.0] void QTextDocument::setSubScriptBaseline(qreal baseline
        )**

        Sets the default subscript's base line as a % of font height to use in
        the document layout to **baseline**. The default value is 16.67% (1/6 of
        height).

        This function was introduced in Qt 6.0.

        **See also** **subScriptBaseline** (), **setSuperScriptBaseline** (),
        **superScriptBaseline** (), **setBaselineOffset** (), and
        **baselineOffset** ().
        """
        ...

    def superScriptBaseline(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#superScriptBaseline

        **[since 6.0] qreal QTextDocument::superScriptBaseline() const**

        Returns the superscript's base line as a % of font height used in the
        document layout.

        This function was introduced in Qt 6.0.

        **See also** **setSuperScriptBaseline** (), **setSubScriptBaseline** (),
        **subScriptBaseline** (), **setBaselineOffset** (), and
        **baselineOffset** ().
        """
        ...

    def setSuperScriptBaseline(self, baseline: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setSuperScriptBaseline

        **[since 6.0] void QTextDocument::setSuperScriptBaseline(qreal baseline
        )**

        Sets the default superscript's base line as a % of font height to use in
        the document layout to **baseline**. The default value is 50% (1/2 of
        height).

        This function was introduced in Qt 6.0.

        **See also** **superScriptBaseline** (), **setSubScriptBaseline** (),
        **subScriptBaseline** (), **setBaselineOffset** (), and
        **baselineOffset** ().
        """
        ...

    def setMarkdown(
        self, markdown: str, features: "QTextDocument.MarkdownFeature" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setMarkdown

        **[since 5.14] void QTextDocument::setMarkdown(const QString & markdown
        , QTextDocument::MarkdownFeatures features = MarkdownDialectGitHub)**

        Replaces the entire contents of the document with the given Markdown-
        formatted text in the **markdown** string, with the given **features**
        supported. By default, all supported GitHub-style Markdown features are
        included; pass `MarkdownDialectCommonMark` for a more basic parse.

        The Markdown formatting is respected as much as possible; for example,
        "*bold* text" will produce text where the first word has a font weight
        that gives it an emphasized appearance.

        Parsing of HTML included in the **markdown** string is handled in the
        same way as in **setHtml** ; however, Markdown formatting inside HTML
        blocks is not supported.

        Some features of the parser can be enabled or disabled via the
        **features** argument:

        ConstantDescription
        `MarkdownNoHTML`Any HTML tags in the Markdown text
        will be discarded
        `MarkdownDialectCommonMark`The parser supports only
        the features standardized by CommonMark
        `MarkdownDialectGitHub`The
        parser supports the GitHub dialect

        The default is `MarkdownDialectGitHub`.

        The undo/redo history is reset when this function is called.

        This function was introduced in Qt 5.14.
        """
        ...

    def toMarkdown(self, features: "QTextDocument.MarkdownFeature" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#toMarkdown

        **[since 5.14] QString
        QTextDocument::toMarkdown(QTextDocument::MarkdownFeatures features =
        MarkdownDialectGitHub) const**

        Returns a string containing a Markdown representation of the document
        with the given **features** , or an empty string if writing fails for
        any reason.

        This function was introduced in Qt 5.14.

        **See also** **setMarkdown** .
        """
        ...

    def toRawText(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#toRawText

        **[since 5.9] QString QTextDocument::toRawText() const**

        Returns the raw text contained in the document without any formatting
        information. If you want formatting information use a **QTextCursor**
        instead.

        This function was introduced in Qt 5.9.

        **See also** **toPlainText** ().
        """
        ...

    def setBaseUrl(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#baseUrl-prop

        **[since 5.3] baseUrl : QUrl**

        This property holds the base URL used to resolve relative resource URLs
        within the document.

        Resource URLs are resolved to be within the same directory as the target
        of the base URL meaning any portion of the path after the last '/' will
        be ignored.

        Base URLRelative URLResolved URL
        file:///path/to/contentimages/logo.pngfile:///path/to/images/logo.png

        file:///path/to/content/images/logo.pngfile:///path/to/content/images/lo
        go.png
        file:///path/to/content/index.htmlimages/logo.pngfile:///path/t
        o/content/images/logo.png
        file:///path/to/content/images/../images/log
        o.pngfile:///path/to/content/images/logo.png

        This property was introduced in Qt 5.3.

        **Access functions:**

        QUrl **baseUrl** () const
        void **setBaseUrl** (const QUrl & **url** )

        **Notifier signal:**

        void **baseUrlChanged** (const QUrl & **url** )
        """
        ...

    def baseUrl(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#baseUrl-prop

        **[since 5.3] baseUrl : QUrl**

        This property holds the base URL used to resolve relative resource URLs
        within the document.

        Resource URLs are resolved to be within the same directory as the target
        of the base URL meaning any portion of the path after the last '/' will
        be ignored.

        Base URLRelative URLResolved URL
        file:///path/to/contentimages/logo.pngfile:///path/to/images/logo.png

        file:///path/to/content/images/logo.pngfile:///path/to/content/images/lo
        go.png
        file:///path/to/content/index.htmlimages/logo.pngfile:///path/t
        o/content/images/logo.png
        file:///path/to/content/images/../images/log
        o.pngfile:///path/to/content/images/logo.png

        This property was introduced in Qt 5.3.

        **Access functions:**

        QUrl **baseUrl** () const
        void **setBaseUrl** (const QUrl & **url** )

        **Notifier signal:**

        void **baseUrlChanged** (const QUrl & **url** )
        """
        ...

    def setDefaultCursorMoveStyle(self, style: QtCore.Qt.CursorMoveStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setDefaultCursorMoveStyle

        **void QTextDocument::setDefaultCursorMoveStyle(Qt::CursorMoveStyle
        style )**

        Sets the default cursor movement style to the given **style**.

        **See also** **defaultCursorMoveStyle** ().
        """
        ...

    def defaultCursorMoveStyle(self) -> QtCore.Qt.CursorMoveStyle:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#defaultCursorMoveStyle

        **Qt::CursorMoveStyle QTextDocument::defaultCursorMoveStyle() const**

        The default cursor movement style is used by all **QTextCursor**
        objects created from the document. The default is
        **Qt::LogicalMoveStyle** .

        **See also** **setDefaultCursorMoveStyle** ().
        """
        ...

    def clearUndoRedoStacks(self, stacks: "QTextDocument.Stacks" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#clearUndoRedoStacks

        **void QTextDocument::clearUndoRedoStacks(QTextDocument::Stacks
        stacksToClear = UndoAndRedoStacks)**

        Clears the stacks specified by **stacksToClear**.

        This method clears any commands on the undo stack, the redo stack, or
        both (the default). If commands are cleared, the appropriate signals are
        emitted, **QTextDocument::undoAvailable** () or
        **QTextDocument::redoAvailable** ().

        **See also** **QTextDocument::undoAvailable** () and
        **QTextDocument::redoAvailable** ().
        """
        ...

    def availableRedoSteps(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#availableRedoSteps

        **int QTextDocument::availableRedoSteps() const**

        Returns the number of available redo steps.

        **See also** **isRedoAvailable** ().
        """
        ...

    def availableUndoSteps(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#availableUndoSteps

        **int QTextDocument::availableUndoSteps() const**

        Returns the number of available undo steps.

        **See also** **isUndoAvailable** ().
        """
        ...

    def characterCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#characterCount

        **int QTextDocument::characterCount() const**

        Returns the number of characters of this document.

        **Note:** As a **QTextDocument**  always contains at least one
        **QChar::ParagraphSeparator** , this method will return at least 1.

        **See also** **blockCount** () and **characterAt** ().
        """
        ...

    def lineCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#lineCount

        **int QTextDocument::lineCount() const**

        Returns the number of lines of this document (if the layout supports
        this). Otherwise, this is identical to the number of blocks.

        **See also** **blockCount** () and **characterCount** ().
        """
        ...

    def setDocumentMargin(self, margin: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#documentMargin-prop

        **documentMargin : qreal**

        The margin around the document. The default is 4.

        **Access functions:**

        qreal **documentMargin** () const
        void **setDocumentMargin** (qreal
        **margin** )
        """
        ...

    def documentMargin(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#documentMargin-prop

        **documentMargin : qreal**

        The margin around the document. The default is 4.

        **Access functions:**

        qreal **documentMargin** () const
        void **setDocumentMargin** (qreal
        **margin** )
        """
        ...

    def characterAt(self, pos: int) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#characterAt

        **QChar QTextDocument::characterAt(int pos ) const**

        Returns the character at position **pos** , or a null character if the
        position is out of range.

        **See also** **characterCount** ().
        """
        ...

    def setIndentWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setIndentWidth

        **void QTextDocument::setIndentWidth(qreal width )**

        Sets the **width** used for text list and text block indenting.

        The indent properties of **QTextListFormat**  and **QTextBlockFormat**
        specify multiples of this value. The default indent width is 40 .

        **Note:** Setter function for property **indentWidth** .

        **See also** **indentWidth** ().
        """
        ...

    def indentWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#indentWidth-prop

        **indentWidth : qreal**

        Returns the width used for text list and text block indenting.

        The indent properties of **QTextListFormat**  and **QTextBlockFormat**
        specify multiples of this value. The default indent width is 40.

        **Access functions:**

        qreal **indentWidth** () const
        void ****setIndentWidth** ** (qreal
        **width** )
        """
        ...

    def lastBlock(self) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#lastBlock

        **QTextBlock QTextDocument::lastBlock() const**

        Returns the document's last (valid) text block.
        """
        ...

    def firstBlock(self) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#firstBlock

        **QTextBlock QTextDocument::firstBlock() const**

        Returns the document's first text block.
        """
        ...

    def findBlockByLineNumber(self, blockNumber: int) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#findBlockByLineNumber

        **QTextBlock QTextDocument::findBlockByLineNumber(int lineNumber )
        const**

        Returns the text block that contains the specified **lineNumber**.

        **See also** **QTextBlock::firstLineNumber** ().
        """
        ...

    def findBlockByNumber(self, blockNumber: int) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#findBlockByNumber

        **QTextBlock QTextDocument::findBlockByNumber(int blockNumber ) const**

        Returns the text block with the specified **blockNumber**.

        **See also** **QTextBlock::blockNumber** ().
        """
        ...

    def revision(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#revision

        **int QTextDocument::revision() const**

        Returns the document's revision (if undo is enabled).

        The revision is guaranteed to increase when a document that is not
        modified is edited.

        **See also** **QTextBlock::revision** () and **isModified** ().
        """
        ...

    def setDefaultTextOption(self, option: "QTextOption") -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setDefaultTextOption

        **void QTextDocument::setDefaultTextOption(const QTextOption & option
        )**

        Sets the default text option to **option**.

        **Note:** Setter function for property **defaultTextOption** .

        **See also** **defaultTextOption** ().
        """
        ...

    def defaultTextOption(self) -> "QTextOption":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#defaultTextOption

        **QTextOption QTextDocument::defaultTextOption() const**

        The default text option is used on all **QTextLayout**  objects in the
        document. This allows setting global properties for the document such as
        the default word wrap mode.

        **Note:** Getter function for property defaultTextOption.

        **See also** **setDefaultTextOption** ().
        """
        ...

    def setMaximumBlockCount(self, maximum: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#maximumBlockCount-prop

        **maximumBlockCount : int**

        Specifies the limit for blocks in the document.

        Specifies the maximum number of blocks the document may have. If there
        are more blocks in the document that specified with this property blocks
        are removed from the beginning of the document.

        A negative or zero value specifies that the document may contain an
        unlimited amount of blocks.

        The default value is 0.

        Note that setting this property will apply the limit immediately to the
        document contents.

        Setting this property also disables the undo redo history.

        This property is undefined in documents with tables or frames.

        **Access functions:**

        int **maximumBlockCount** () const
        void **setMaximumBlockCount** (int
        **maximum** )
        """
        ...

    def maximumBlockCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#maximumBlockCount-prop

        **maximumBlockCount : int**

        Specifies the limit for blocks in the document.

        Specifies the maximum number of blocks the document may have. If there
        are more blocks in the document that specified with this property blocks
        are removed from the beginning of the document.

        A negative or zero value specifies that the document may contain an
        unlimited amount of blocks.

        The default value is 0.

        Note that setting this property will apply the limit immediately to the
        document contents.

        Setting this property also disables the undo redo history.

        This property is undefined in documents with tables or frames.

        **Access functions:**

        int **maximumBlockCount** () const
        void **setMaximumBlockCount** (int
        **maximum** )
        """
        ...

    def defaultStyleSheet(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#defaultStyleSheet-prop

        **defaultStyleSheet : QString**

        The default style sheet is applied to all newly HTML formatted text that
        is inserted into the document, for example using **setHtml** () or
        **QTextCursor::insertHtml** ().

        The style sheet needs to be compliant to CSS 2.1 syntax.

        **Note:** Changing the default style sheet does not have any effect to
        the existing content of the document.

        **Access functions:**

        QString **defaultStyleSheet** () const
        void **setDefaultStyleSheet**
        (const QString & **sheet** )

        **See also** **Supported HTML Subset** .
        """
        ...

    def setDefaultStyleSheet(self, sheet: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#defaultStyleSheet-prop

        **defaultStyleSheet : QString**

        The default style sheet is applied to all newly HTML formatted text that
        is inserted into the document, for example using **setHtml** () or
        **QTextCursor::insertHtml** ().

        The style sheet needs to be compliant to CSS 2.1 syntax.

        **Note:** Changing the default style sheet does not have any effect to
        the existing content of the document.

        **Access functions:**

        QString **defaultStyleSheet** () const
        void **setDefaultStyleSheet**
        (const QString & **sheet** )

        **See also** **Supported HTML Subset** .
        """
        ...

    def blockCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#blockCount-prop

        **[read-only] blockCount : const int**

        This property holds the number of text blocks in the document.

        The value of this property is undefined in documents with tables or
        frames.

        By default, if defined, this property contains a value of 1.

        **Access functions:**

        int **blockCount** () const

        **See also** **lineCount** () and **characterCount** ().
        """
        ...

    def size(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#size-prop

        **[read-only] size : const QSizeF**

        This property holds the actual size of the document. This is equivalent
        to **documentLayout** ()->documentSize();

        The size of the document can be changed either by setting a text width
        or setting an entire page size.

        Note that the width is always >= **pageSize** ().width().

        By default, for a newly-created, empty document, this property contains
        a configuration-dependent size.

        **Access functions:**

        QSizeF **size** () const

        **See also** **setTextWidth** (), **setPageSize** (), and **idealWidth**
        ().
        """
        ...

    def adjustSize(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#adjustSize

        **void QTextDocument::adjustSize()**

        Adjusts the document to a reasonable size.

        **See also** **idealWidth** (), **textWidth** , and **size** .
        """
        ...

    def idealWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#idealWidth

        **qreal QTextDocument::idealWidth() const**

        Returns the ideal width of the text document. The ideal width is the
        actually used width of the document without optional alignments taken
        into account. It is always <= **size** ().width().

        **See also** **adjustSize** () and **textWidth** .
        """
        ...

    def textWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#textWidth-prop

        **textWidth : qreal**

        The text width specifies the preferred width for text in the document.
        If the text (or content in general) is wider than the specified with it
        is broken into multiple lines and grows vertically. If the text cannot
        be broken into multiple lines to fit into the specified text width it
        will be larger and the **size** () and the **idealWidth** () property
        will reflect that.

        If the text width is set to -1 then the text will not be broken into
        multiple lines unless it is enforced through an explicit line break or a
        new paragraph.

        The default value is -1.

        Setting the text width will also set the page height to -1, causing the
        document to grow or shrink vertically in a continuous way. If you want
        the document layout to break the text into multiple pages then you have
        to set the **pageSize**  property instead.

        **Access functions:**

        qreal **textWidth** () const
        void **setTextWidth** (qreal **width** )

        **See also** **size** (), **idealWidth** (), and **pageSize** ().
        """
        ...

    def setTextWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#textWidth-prop

        **textWidth : qreal**

        The text width specifies the preferred width for text in the document.
        If the text (or content in general) is wider than the specified with it
        is broken into multiple lines and grows vertically. If the text cannot
        be broken into multiple lines to fit into the specified text width it
        will be larger and the **size** () and the **idealWidth** () property
        will reflect that.

        If the text width is set to -1 then the text will not be broken into
        multiple lines unless it is enforced through an explicit line break or a
        new paragraph.

        The default value is -1.

        Setting the text width will also set the page height to -1, causing the
        document to grow or shrink vertically in a continuous way. If you want
        the document layout to break the text into multiple pages then you have
        to set the **pageSize**  property instead.

        **Access functions:**

        qreal **textWidth** () const
        void **setTextWidth** (qreal **width** )

        **See also** **size** (), **idealWidth** (), and **pageSize** ().
        """
        ...

    def drawContents(self, p: QPainter, rect: QtCore.QRectF = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#drawContents

        **void QTextDocument::drawContents(QPainter * p , const QRectF & rect =
        QRectF())**

        Draws the content of the document with painter **p** , clipped to
        **rect**. If **rect** is a null rectangle (default) then the document is
        painted unclipped.
        """
        ...

    def loadResource(self, type: int, name: QtCore.QUrl) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#loadResource

        **[virtual protected invokable] QVariant QTextDocument::loadResource(int
        type , const QUrl & name )**

        Loads data of the specified **type** from the resource with the given
        **name**.

        This function is called by the rich text engine to request data that
        isn't directly stored by **QTextDocument** , but still associated with
        it. For example, images are referenced indirectly by the name attribute
        of a **QTextImageFormat**  object.

        When called by Qt, **type** is one of the values of
        **QTextDocument::ResourceType** .

        If the **QTextDocument**  is a child object of a **QObject**  that has
        an invokable loadResource method such as **QTextEdit** ,
        **QTextBrowser**  or a **QTextDocument**  itself then the default
        implementation tries to retrieve the data from the parent.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **QTextDocument::ResourceProvider** .
        """
        ...

    def createObject(self, f: "QTextFormat") -> "QTextObject":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#createObject

        **[virtual protected] QTextObject *QTextDocument::createObject(const
        QTextFormat & format )**

        Creates and returns a new document object (a **QTextObject** ), based on
        the given **format**.

        QTextObjects will always get created through this method, so you must
        reimplement it if you use custom text objects inside your document.
        """
        ...

    def setModified(self, on: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#modified-prop

        **modified : bool**

        This property holds whether the document has been modified by the user

        By default, this property is `false`.

        **Access functions:**

        bool **isModified** () const
        void **setModified** (bool **m** = true)

        **See also** **modificationChanged** ().
        """
        ...

    @typing.overload
    def redo(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#redo

        **void QTextDocument::redo(QTextCursor * cursor )**

        Redoes the last editing operation on the document if **redo is
        available** .

        The provided **cursor** is positioned at the end of the location where
        the edition operation was redone.
        """
        ...

    @typing.overload
    def redo(self, cursor: QTextCursor) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#redo-1

        **[slot] void QTextDocument::redo()**

        This is an overloaded function.

        Redoes the last editing operation on the document if **redo is
        available** .
        """
        ...

    @typing.overload
    def undo(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#undo

        **void QTextDocument::undo(QTextCursor * cursor )**

        Undoes the last editing operation on the document if undo is available.
        The provided **cursor** is positioned at the end of the location where
        the edition operation was undone.

        See the **Qt Undo Framework**  documentation for details.

        **See also** **undoAvailable** () and **isUndoRedoEnabled** ().
        """
        ...

    @typing.overload
    def undo(self, cursor: QTextCursor) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#undo-1

        **[slot] void QTextDocument::undo()**

        This is an overloaded function.
        """
        ...

    def useDesignMetrics(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#useDesignMetrics-prop

        **useDesignMetrics : bool**

        This property holds whether the document uses design metrics of fonts to
        improve the accuracy of text layout

        If this property is set to true, the layout will use design metrics.
        Otherwise, the metrics of the paint device as set on
        **QAbstractTextDocumentLayout::setPaintDevice** () will be used.

        Using design metrics makes a layout have a width that is no longer
        dependent on hinting and pixel-rounding. This means that WYSIWYG text
        layout becomes possible because the width scales much more linearly
        based on paintdevice metrics than it would otherwise.

        By default, this property is `false`.

        **Access functions:**

        bool **useDesignMetrics** () const
        void **setUseDesignMetrics** (bool
        **b** )

        **Member Function Documentation**
        """
        ...

    def setUseDesignMetrics(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#useDesignMetrics-prop

        **useDesignMetrics : bool**

        This property holds whether the document uses design metrics of fonts to
        improve the accuracy of text layout

        If this property is set to true, the layout will use design metrics.
        Otherwise, the metrics of the paint device as set on
        **QAbstractTextDocumentLayout::setPaintDevice** () will be used.

        Using design metrics makes a layout have a width that is no longer
        dependent on hinting and pixel-rounding. This means that WYSIWYG text
        layout becomes possible because the width scales much more linearly
        based on paintdevice metrics than it would otherwise.

        By default, this property is `false`.

        **Access functions:**

        bool **useDesignMetrics** () const
        void **setUseDesignMetrics** (bool
        **b** )

        **Member Function Documentation**
        """
        ...

    def markContentsDirty(self, from_: int, length: int) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#markContentsDirty

        **void QTextDocument::markContentsDirty(int position , int length )**

        Marks the contents specified by the given **position** and **length** as
        "dirty", informing the document that it needs to be laid out again.
        """
        ...

    def allFormats(self) -> typing.List["QTextFormat"]:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#allFormats

        **QList<QTextFormat> QTextDocument::allFormats() const**

        Returns a list of text formats for all the formats used in the document.
        """
        ...

    def addResource(self, type: int, name: QtCore.QUrl, resource: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#addResource

        **void QTextDocument::addResource(int type , const QUrl & name , const
        QVariant & resource )**

        Adds the resource **resource** to the resource cache, using **type** and
        **name** as identifiers. **type** should be a value from
        **QTextDocument::ResourceType** .

        For example, you can add an image as a resource in order to reference it
        from within the document:

        document->addResource(**QTextDocument** ::ImageResource,
        **QUrl** ("mydata://image.png"), **QVariant** (image));

        The image can be inserted into the document using the **QTextCursor**
        API:

        **QTextImageFormat**  imageFormat;
        imageFormat.setName("mydata://image.png");
        cursor.insertImage(imageFormat);

        Alternatively, you can insert images using the HTML `img` tag:

        editor->append("<img src=\\"mydata://image.png\\" />");
        """
        ...

    def resource(self, type: int, name: QtCore.QUrl) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#resource

        **QVariant QTextDocument::resource(int type , const QUrl & name )
        const**

        Returns data of the specified **type** from the resource with the given
        **name**.

        This function is called by the rich text engine to request data that
        isn't directly stored by **QTextDocument** , but still associated with
        it. For example, images are referenced indirectly by the name attribute
        of a **QTextImageFormat**  object.

        Resources are cached internally in the document. If a resource can not
        be found in the cache, **loadResource**  is called to try to load the
        resource. **loadResource**  should then use **addResource**  to add the
        resource to the cache.

        If **loadResource**  does not load the resource, then the
        **resourceProvider**  and lastly the **defaultResourceProvider**  will
        be called, if set. Note that the result from the provider will not be
        added automatically to the cache.

        **See also** **QTextDocument::ResourceType**  and **resourceProvider**
        ().
        """
        ...

    def print(self, printer: QPagedPaintDevice) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#print

        **void QTextDocument::print(QPagedPaintDevice * printer ) const**

        Prints the document to the given **printer**. The **QPagedPaintDevice**
        must be set up before being used with this function.

        This is only a convenience method to print the whole document to the
        printer.

        If the document is already paginated through a specified height in the
        **pageSize** () property it is printed as-is.

        If the document is not paginated, like for example a document used in a
        **QTextEdit** , then a temporary copy of the document is created and the
        copy is broken into multiple pages according to the size of the paint
        device's paperRect(). By default a 2 cm margin is set around the
        document contents. In addition the current page number is printed at the
        bottom of each page.

        **See also** **QTextEdit::print** ().
        """
        ...

    def isModified(self) -> bool:
        ...

    def pageCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#pageCount

        **int QTextDocument::pageCount() const**

        returns the number of pages in this document.
        """
        ...

    def defaultFont(self) -> QFont:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#defaultFont

        **QFont QTextDocument::defaultFont() const**

        Returns the default font to be used in the document layout.

        **Note:** Getter function for property defaultFont.

        **See also** **setDefaultFont** ().
        """
        ...

    def setDefaultFont(self, font: QFont) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setDefaultFont

        **void QTextDocument::setDefaultFont(const QFont & font )**

        Sets the default **font** to use in the document layout.

        **Note:** Setter function for property **defaultFont** .

        **See also** **defaultFont** ().
        """
        ...

    def pageSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#pageSize-prop

        **pageSize : QSizeF**

        This property holds the page size that should be used for laying out the
        document

        The units are determined by the underlying paint device. The size is
        measured in logical pixels when painting to the screen, and in points
        (1/72 inch) when painting to a printer.

        By default, for a newly-created, empty document, this property contains
        an undefined size.

        **Access functions:**

        QSizeF **pageSize** () const
        void **setPageSize** (const QSizeF &
        **size** )

        **See also** **modificationChanged** ().
        """
        ...

    def setPageSize(self, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#pageSize-prop

        **pageSize : QSizeF**

        This property holds the page size that should be used for laying out the
        document

        The units are determined by the underlying paint device. The size is
        measured in logical pixels when painting to the screen, and in points
        (1/72 inch) when painting to a printer.

        By default, for a newly-created, empty document, this property contains
        an undefined size.

        **Access functions:**

        QSizeF **pageSize** () const
        void **setPageSize** (const QSizeF &
        **size** )

        **See also** **modificationChanged** ().
        """
        ...

    def end(self) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#end

        **QTextBlock QTextDocument::end() const**

        This function returns a block to test for the end of the document while
        iterating over it.

        for (**QTextBlock**  it = doc->begin(); it != doc->end(); it =
        it.next())
                std::cout << it.text().toStdString() << "\\n";

        The block returned is invalid and represents the block after the last
        block in the document. You can use **lastBlock** () to retrieve the last
        valid block of the document.

        **See also** **lastBlock** ().
        """
        ...

    def begin(self) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#begin

        **QTextBlock QTextDocument::begin() const**

        Returns the document's first text block.

        **See also** **firstBlock** ().
        """
        ...

    def findBlock(self, pos: int) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#findBlock

        **QTextBlock QTextDocument::findBlock(int pos ) const**

        Returns the text block that contains the **pos** -th character.
        """
        ...

    def objectForFormat(self, a0: "QTextFormat") -> "QTextObject":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#objectForFormat

        **QTextObject *QTextDocument::objectForFormat(const QTextFormat & f )
        const**

        Returns the text object associated with the format **f**.
        """
        ...

    def object(self, objectIndex: int) -> "QTextObject":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#object

        **QTextObject *QTextDocument::object(int objectIndex ) const**

        Returns the text object associated with the given **objectIndex**.
        """
        ...

    def rootFrame(self) -> "QTextFrame":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#rootFrame

        **QTextFrame *QTextDocument::rootFrame() const**

        Returns the document's root frame.
        """
        ...

    @typing.overload
    def find(
        self,
        expr: QtCore.QRegularExpression,
        cursor: QTextCursor,
        options: "QTextDocument.FindFlag" = ...,
    ) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#find

        **QTextCursor QTextDocument::find(const QString & subString , const
        QTextCursor & cursor , QTextDocument::FindFlags options = FindFlags())
        const**

        Finds the next occurrence of the string, **subString** , in the
        document. The search starts at the position of the given **cursor** ,
        and proceeds forwards through the document unless specified otherwise in
        the search options. The **options** control the type of search
        performed.

        Returns a cursor with the match selected if **subString** was found;
        otherwise returns a null cursor.

        If the given **cursor** has a selection, the search begins after the
        selection; otherwise it begins at the cursor's position.

        By default the search is case insensitive, and can match text anywhere
        in the document.
        """
        ...

    @typing.overload
    def find(
        self,
        expr: QtCore.QRegularExpression,
        position: int = ...,
        options: "QTextDocument.FindFlag" = ...,
    ) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#find-1

        **QTextCursor QTextDocument::find(const QString & subString , int
        position = 0, QTextDocument::FindFlags options = FindFlags()) const**

        This is an overloaded function.

        Finds the next occurrence of the string, **subString** , in the
        document. The search starts at the given **position** , and proceeds
        forwards through the document unless specified otherwise in the search
        options. The **options** control the type of search performed.

        Returns a cursor with the match selected if **subString** was found;
        otherwise returns a null cursor.

        If the **position** is 0 (the default) the search begins from the
        beginning of the document; otherwise it begins at the specified
        position.
        """
        ...

    @typing.overload
    def find(
        self,
        subString: str,
        cursor: QTextCursor,
        options: "QTextDocument.FindFlag" = ...,
    ) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#find-2

        **[since 5.5] QTextCursor QTextDocument::find(const QRegularExpression &
        expr , int from = 0, QTextDocument::FindFlags options = FindFlags())
        const**

        Finds the next occurrence that matches the given regular expression,
        **expr** , within the same paragraph in the document.

        The search starts at the given **from** position, and proceeds forwards
        through the document unless specified otherwise in the search options.
        The **options** control the type of search performed.

        Returns a cursor with the match selected if a match was found; otherwise
        returns a null cursor.

        If the **from** position is 0 (the default) the search begins from the
        beginning of the document; otherwise it begins at the specified
        position.

        This function was introduced in Qt 5.5.
        """
        ...

    @typing.overload
    def find(
        self,
        subString: str,
        position: int = ...,
        options: "QTextDocument.FindFlag" = ...,
    ) -> QTextCursor:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#find-3

        **[since 5.5] QTextCursor QTextDocument::find(const QRegularExpression &
        expr , const QTextCursor & cursor , QTextDocument::FindFlags options =
        FindFlags()) const**

        Finds the next occurrence that matches the given regular expression,
        **expr** , within the same paragraph in the document.

        The search starts at the position of the given **cursor** , and proceeds
        forwards through the document unless specified otherwise in the search
        options. The **options** control the type of search performed.

        Returns a cursor with the match selected if a match was found; otherwise
        returns a null cursor.

        If the given **cursor** has a selection, the search begins after the
        selection; otherwise it begins at the cursor's position.

        By default the search is case insensitive, and can match text anywhere
        in the document.

        This function was introduced in Qt 5.5.
        """
        ...

    def setPlainText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setPlainText

        **void QTextDocument::setPlainText(const QString & text )**

        Replaces the entire contents of the document with the given plain
        **text**. The undo/redo history is reset when this function is called.

        **See also** **setHtml** ().
        """
        ...

    def toPlainText(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#toPlainText

        **QString QTextDocument::toPlainText() const**

        Returns the plain text contained in the document. If you want formatting
        information use a **QTextCursor**  instead.

        This function returns the same as **toRawText** (), but will replace
        some unicode characters with ASCII alternatives. In particular, no-break
        space (U+00A0) is replaced by a regular space (U+0020), and both
        paragraph (U+2029) and line (U+2028) separators are replaced by line
        feed (U+000A). If you need the precise contents of the document, use
        **toRawText** () instead.

        **Note:** Embedded objects, such as images, are represented by a Unicode
        value U+FFFC (OBJECT REPLACEMENT CHARACTER).

        **See also** **toHtml** ().
        """
        ...

    def setHtml(self, html: str) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setHtml

        **void QTextDocument::setHtml(const QString & html )**

        Replaces the entire contents of the document with the given HTML-
        formatted text in the **html** string. The undo/redo history is reset
        when this function is called.

        The HTML formatting is respected as much as possible; for example,
        "<b>bold</b> text" will produce text where the first word has a font
        weight that gives it a bold appearance: " **bold** text".

        **Note:** It is the responsibility of the caller to make sure that the
        text is correctly decoded when a **QString**  containing HTML is created
        and passed to setHtml().

        **See also** **setPlainText** () and **Supported HTML Subset** .
        """
        ...

    def toHtml(self) -> str:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#toHtml

        **QString QTextDocument::toHtml() const**

        Returns a string containing an HTML representation of the document.

        The content of the document specifies its encoding to be UTF-8. If you
        later on convert the returned html string into a byte array for
        transmission over a network or when saving to disk you should use
        **QString::toUtf8** () to convert the string to a **QByteArray** .

        **See also** **Supported HTML Subset** .
        """
        ...

    def metaInformation(self, info: "QTextDocument.MetaInformation") -> str:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#metaInformation

        **QString QTextDocument::metaInformation(QTextDocument::MetaInformation
        info ) const**

        Returns meta information about the document of the type specified by
        **info**.

        **See also** **setMetaInformation** ().
        """
        ...

    def setMetaInformation(
        self, info: "QTextDocument.MetaInformation", a1: str
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setMetaInformation

        **void QTextDocument::setMetaInformation(QTextDocument::MetaInformation
        info , const QString & string )**

        Sets the document's meta information of the type specified by **info**
        to the given **string**.

        **See also** **metaInformation** ().
        """
        ...

    def documentLayout(self) -> QAbstractTextDocumentLayout:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#documentLayout

        **QAbstractTextDocumentLayout *QTextDocument::documentLayout() const**

        Returns the document layout for this document.

        **See also** **setDocumentLayout** ().
        """
        ...

    def setDocumentLayout(self, layout: QAbstractTextDocumentLayout) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#setDocumentLayout

        **void QTextDocument::setDocumentLayout(QAbstractTextDocumentLayout *
        layout )**

        Sets the document to use the given **layout**. The previous layout is
        deleted.

        **See also** **documentLayoutChanged** ().
        """
        ...

    def isRedoAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#isRedoAvailable

        **bool QTextDocument::isRedoAvailable() const**

        Returns `true` if redo is available; otherwise returns `false`.

        **See also** **isUndoAvailable** () and **availableRedoSteps** ().
        """
        ...

    def isUndoAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#isUndoAvailable

        **bool QTextDocument::isUndoAvailable() const**

        Returns `true` if undo is available; otherwise returns `false`.

        **See also** **isRedoAvailable** () and **availableUndoSteps** ().
        """
        ...

    def isUndoRedoEnabled(self) -> bool:
        ...

    def setUndoRedoEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#undoRedoEnabled-prop

        **undoRedoEnabled : bool**

        This property holds whether undo/redo are enabled for this document

        This defaults to true. If disabled, the undo stack is cleared and no
        items will be added to it.

        **Access functions:**

        bool **isUndoRedoEnabled** () const
        void **setUndoRedoEnabled** (bool
        **enable** )
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#clear

        **[virtual] void QTextDocument::clear()**

        Clears the document.
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#isEmpty

        **bool QTextDocument::isEmpty() const**

        Returns `true` if the document is empty; otherwise returns `false`.
        """
        ...

    def clone(self, parent: typing.Optional[QtCore.QObject] = ...) -> "QTextDocument":
        """
        https://doc.qt.io/qt-6/qtextdocument.html#clone

        **QTextDocument *QTextDocument::clone(QObject * parent = nullptr)
        const**

        Creates a new **QTextDocument**  that is a copy of this text document.
        **parent** is the parent of the returned text document.
        """
        ...

    @property
    def baseUrlChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def blockCountChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#blockCountChanged

        **[signal] void QTextDocument::blockCountChanged(int newBlockCount )**

        This signal is emitted when the total number of text blocks in the
        document changes. The value passed in **newBlockCount** is the new
        total.
        """
        ...

    @property
    def contentsChange(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#contentsChange

        **[signal] void QTextDocument::contentsChange(int position , int
        charsRemoved , int charsAdded )**

        This signal is emitted whenever the document's content changes; for
        example, when text is inserted or deleted, or when formatting is
        applied.

        Information is provided about the **position** of the character in the
        document where the change occurred, the number of characters removed (
        **charsRemoved** ), and the number of characters added ( **charsAdded**
        ).

        The signal is emitted before the document's layout manager is notified
        about the change. This hook allows you to implement syntax highlighting
        for the document.

        **See also** **QAbstractTextDocumentLayout::documentChanged** () and
        **contentsChanged** ().
        """
        ...

    @property
    def contentsChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#contentsChanged

        **[signal] void QTextDocument::contentsChanged()**

        This signal is emitted whenever the document's content changes; for
        example, when text is inserted or deleted, or when formatting is
        applied.

        **See also** **contentsChange** ().
        """
        ...

    @property
    def cursorPositionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#cursorPositionChanged

        **[signal] void QTextDocument::cursorPositionChanged(const QTextCursor &
        cursor )**

        This signal is emitted whenever the position of a cursor changed due to
        an editing operation. The cursor that changed is passed in **cursor**.
        If the document is used with the **QTextEdit**  class and you need a
        signal when the cursor is moved with the arrow keys you can use the
        **cursorPositionChanged** () signal in **QTextEdit** .
        """
        ...

    @property
    def documentLayoutChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#documentLayoutChanged

        **[signal] void QTextDocument::documentLayoutChanged()**

        This signal is emitted when a new document layout is set.

        **See also** **setDocumentLayout** ().
        """
        ...

    @property
    def modificationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#modificationChanged

        **[signal] void QTextDocument::modificationChanged(bool changed )**

        This signal is emitted whenever the content of the document changes in a
        way that affects the modification state. If **changed** is true, the
        document has been modified; otherwise it is false.

        For example, calling **setModified** (false) on a document and then
        inserting text causes the signal to get emitted. If you undo that
        operation, causing the document to return to its original unmodified
        state, the signal will get emitted again.
        """
        ...

    @property
    def redoAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#redoAvailable

        **[signal] void QTextDocument::redoAvailable(bool available )**

        This signal is emitted whenever redo operations become available (
        **available** is true) or unavailable ( **available** is false).
        """
        ...

    @property
    def undoAvailable(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#undoAvailable

        **[signal] void QTextDocument::undoAvailable(bool available )**

        This signal is emitted whenever undo operations become available (
        **available** is true) or unavailable ( **available** is false).

        See the **Qt Undo Framework**  documentation for details.

        **See also** **undo** () and **isUndoRedoEnabled** ().
        """
        ...

    @property
    def undoCommandAdded(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtextdocument.html#undoCommandAdded

        **[signal] void QTextDocument::undoCommandAdded()**

        This signal is emitted every time a new level of undo is added to the
        **QTextDocument** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
import datetime
from PyQt6.QtWidgets import *
import enum


class QDateTimeEdit(QAbstractSpinBox):
    """
    https://doc.qt.io/qt-6/qdatetimeedit.html

    **Detailed Description**

    ![](images/windows-datetimeedit.png)

    QDateTimeEdit allows the user to edit dates by using the keyboard or the
    arrow keys to increase and decrease date and time values. The arrow keys can
    be used to move from section to section within the QDateTimeEdit box. Dates
    and times appear in accordance with the format set; see **setDisplayFormat**
    ().

    **QDateTimeEdit**  *dateEdit = new **QDateTimeEdit** (**QDate**
    ::currentDate());
        dateEdit->setMinimumDate(**QDate**
    ::currentDate().addDays(-365));
        dateEdit->setMaximumDate(**QDate**
    ::currentDate().addDays(365));
        dateEdit->setDisplayFormat("yyyy.MM.dd");

    Here we've created a new QDateTimeEdit object initialized with today's date,
    and restricted the valid date range to today plus or minus 365 days. We've
    set the order to month, day, year.

    The range of valid values for a QDateTimeEdit is controlled by the
    properties **minimumDateTime** , **maximumDateTime** , and their respective
    date and time components. By default, any date-time from the start of 100 CE
    to the end of 9999 CE is valid.

    **Using a Pop-up Calendar Widget**

    QDateTimeEdit can be configured to allow a **QCalendarWidget**  to be used
    to select dates. This is enabled by setting the **calendarPopup**  property.
    Additionally, you can supply a custom calendar widget for use as the
    calendar pop-up by calling the **setCalendarWidget** () function. The
    existing calendar widget can be retrieved with **calendarWidget** ().

    **Keyboard Tracking**

    When **keyboard tracking**  is enabled (the default), every keystroke of
    editing a field triggers signals for value changes.

    When the allowed **range**  is narrower than some time interval whose end it
    straddles, keyboard tracking prevents the user editing the date or time to
    access the later part of the interval. For example, for a range from
    29.04.2020 to 02.05.2020 and an initial date of 30.04.2020, the user can
    change neither the month (May 30th is outside the range) nor the day (April
    2nd is outside the range).

    When keyboard tracking is disabled, changes are only signalled when focus
    leaves the text field after edits have modified the content. This allows the
    user to edit via an invalid date-time to reach a valid one.

    **See also** **QDateEdit** , **QTimeEdit** , **QDate** , and **QTime** .
    """

    class Section(enum.Flag):
        NoSection: QDateTimeEdit = ...
        AmPmSection: QDateTimeEdit = ...
        MSecSection: QDateTimeEdit = ...
        SecondSection: QDateTimeEdit = ...
        MinuteSection: QDateTimeEdit = ...
        HourSection: QDateTimeEdit = ...
        DaySection: QDateTimeEdit = ...
        MonthSection: QDateTimeEdit = ...
        YearSection: QDateTimeEdit = ...
        TimeSections_Mask: QDateTimeEdit = ...
        DateSections_Mask: QDateTimeEdit = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#QDateTimeEdit

        **QDateTimeEdit::QDateTimeEdit(QWidget * parent = nullptr)**

        Constructs an empty date time editor with a **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        datetime: typing.Union[QtCore.QDateTime, datetime.datetime],
        parent: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#QDateTimeEdit-1

        **QDateTimeEdit::QDateTimeEdit(const QDateTime & datetime , QWidget *
        parent = nullptr)**

        Constructs an empty date time editor with a **parent**. The value is set
        to **datetime**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        d: typing.Union[QtCore.QDate, datetime.date],
        parent: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#QDateTimeEdit-2

        **QDateTimeEdit::QDateTimeEdit(QDate date , QWidget * parent =
        nullptr)**

        Constructs an empty date time editor with a **parent**. The value is set
        to **date**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        t: typing.Union[QtCore.QTime, datetime.time],
        parent: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#QDateTimeEdit-3

        **QDateTimeEdit::QDateTimeEdit(QTime time , QWidget * parent =
        nullptr)**

        Constructs an empty date time editor with a **parent**. The value is set
        to **time**.
        """
        ...

    def setCalendar(self, calendar: QtCore.QCalendar) -> None:
        ...

    def calendar(self) -> QtCore.QCalendar:
        ...

    def setTimeSpec(self, spec: QtCore.Qt.TimeSpec) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#timeSpec-prop

        **timeSpec : Qt::TimeSpec**

        This property holds the current timespec used by the date time edit.

        **Access functions:**

        Qt::TimeSpec **timeSpec** () const
        void **setTimeSpec** (Qt::TimeSpec
        **spec** )

        **Member Function Documentation**
        """
        ...

    def timeSpec(self) -> QtCore.Qt.TimeSpec:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#timeSpec-prop

        **timeSpec : Qt::TimeSpec**

        This property holds the current timespec used by the date time edit.

        **Access functions:**

        Qt::TimeSpec **timeSpec** () const
        void **setTimeSpec** (Qt::TimeSpec
        **spec** )

        **Member Function Documentation**
        """
        ...

    def setCalendarWidget(self, calendarWidget: QCalendarWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#setCalendarWidget

        **void QDateTimeEdit::setCalendarWidget(QCalendarWidget * calendarWidget
        )**

        Sets the given **calendarWidget** as the widget to be used for the
        calendar pop-up. The editor does not automatically take ownership of the
        calendar widget.

        **Note:****calendarPopup**  must be set to true before setting the
        calendar widget.

        **See also** **calendarWidget** () and **calendarPopup** .
        """
        ...

    def calendarWidget(self) -> QCalendarWidget:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#calendarWidget

        **QCalendarWidget *QDateTimeEdit::calendarWidget() const**

        Returns the calendar widget for the editor if **calendarPopup**  is set
        to true and (sections() & **DateSections_Mask** ) != 0.

        This function creates and returns a calendar widget if none has been
        set.

        **See also** **setCalendarWidget** ().
        """
        ...

    def setDateTimeRange(
        self,
        min: typing.Union[QtCore.QDateTime, datetime.datetime],
        max: typing.Union[QtCore.QDateTime, datetime.datetime],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#setDateTimeRange

        **void QDateTimeEdit::setDateTimeRange(const QDateTime & min , const
        QDateTime & max )**

        Set the range of allowed date-times for the date time edit.

        This convenience function sets the **minimumDateTime**  and
        **maximumDateTime**  properties.

        setDateTimeRange(min, max);

        is analogous to:

        setMinimumDateTime(min);
            setMaximumDateTime(max);

        If either **min** or **max** is invalid, this function does nothing. If
        **max** is less than **min** , **min** is used also as **max**.

        If the range is narrower then a time interval whose end it spans, for
        example a week that spans the end of a month, users can only edit the
        date-time to one in the later part of the range if keyboard-tracking is
        disabled.

        **See also** **minimumDateTime** , **maximumDateTime** ,
        **setDateRange** (), **setTimeRange** (), **QDateTime::isValid** (), and
        **Keyboard Tracking** .
        """
        ...

    def setMaximumDateTime(
        self, dt: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#maximumDateTime-prop

        **maximumDateTime : QDateTime**

        This property holds the maximum datetime of the date time edit.

        Changing this property implicitly updates the **maximumDate**  and
        **maximumTime**  properties to the date and time parts of this property,
        respectively. When setting this property, the **minimumDateTime**  is
        adjusted, if necessary, to ensure that the range remains valid.
        Otherwise, changing this property preserves the **minimumDateTime**
        property.

        This property can only be set to a valid **QDateTime**  value. The
        latest date-time that setMaximumDateTime() accepts is the end of 9999
        CE. This is the default for this property. This default can be restored
        with clearMaximumDateTime().

        **Access functions:**

        QDateTime **maximumDateTime** () const
        void **setMaximumDateTime**
        (const QDateTime & **dt** )
        void **clearMaximumDateTime** ()

        **See also** **minimumDateTime** , **maximumTime** , **maximumDate** (),
        **setDateTimeRange** (), **QDateTime::isValid** (), and **Keyboard
        Tracking** .
        """
        ...

    def clearMaximumDateTime(self) -> None:
        ...

    def maximumDateTime(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#maximumDateTime-prop

        **maximumDateTime : QDateTime**

        This property holds the maximum datetime of the date time edit.

        Changing this property implicitly updates the **maximumDate**  and
        **maximumTime**  properties to the date and time parts of this property,
        respectively. When setting this property, the **minimumDateTime**  is
        adjusted, if necessary, to ensure that the range remains valid.
        Otherwise, changing this property preserves the **minimumDateTime**
        property.

        This property can only be set to a valid **QDateTime**  value. The
        latest date-time that setMaximumDateTime() accepts is the end of 9999
        CE. This is the default for this property. This default can be restored
        with clearMaximumDateTime().

        **Access functions:**

        QDateTime **maximumDateTime** () const
        void **setMaximumDateTime**
        (const QDateTime & **dt** )
        void **clearMaximumDateTime** ()

        **See also** **minimumDateTime** , **maximumTime** , **maximumDate** (),
        **setDateTimeRange** (), **QDateTime::isValid** (), and **Keyboard
        Tracking** .
        """
        ...

    def setMinimumDateTime(
        self, dt: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#minimumDateTime-prop

        **minimumDateTime : QDateTime**

        This property holds the minimum datetime of the date time edit.

        Changing this property implicitly updates the **minimumDate**  and
        **minimumTime**  properties to the date and time parts of this property,
        respectively. When setting this property, the **maximumDateTime**  is
        adjusted, if necessary, to ensure that the range remains valid.
        Otherwise, changing this property preserves the **maximumDateTime**
        property.

        This property can only be set to a valid **QDateTime**  value. The
        earliest date-time that setMinimumDateTime() accepts is the start of 100
        CE. The property's default is the start of September 14, 1752 CE. This
        default can be restored with clearMinimumDateTime().

        **Access functions:**

        QDateTime **minimumDateTime** () const
        void **setMinimumDateTime**
        (const QDateTime & **dt** )
        void **clearMinimumDateTime** ()

        **See also** **maximumDateTime** , **minimumTime** , **minimumDate** ,
        **setDateTimeRange** (), **QDateTime::isValid** (), and **Keyboard
        Tracking** .
        """
        ...

    def clearMinimumDateTime(self) -> None:
        ...

    def minimumDateTime(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#minimumDateTime-prop

        **minimumDateTime : QDateTime**

        This property holds the minimum datetime of the date time edit.

        Changing this property implicitly updates the **minimumDate**  and
        **minimumTime**  properties to the date and time parts of this property,
        respectively. When setting this property, the **maximumDateTime**  is
        adjusted, if necessary, to ensure that the range remains valid.
        Otherwise, changing this property preserves the **maximumDateTime**
        property.

        This property can only be set to a valid **QDateTime**  value. The
        earliest date-time that setMinimumDateTime() accepts is the start of 100
        CE. The property's default is the start of September 14, 1752 CE. This
        default can be restored with clearMinimumDateTime().

        **Access functions:**

        QDateTime **minimumDateTime** () const
        void **setMinimumDateTime**
        (const QDateTime & **dt** )
        void **clearMinimumDateTime** ()

        **See also** **maximumDateTime** , **minimumTime** , **minimumDate** ,
        **setDateTimeRange** (), **QDateTime::isValid** (), and **Keyboard
        Tracking** .
        """
        ...

    def stepEnabled(self) -> QAbstractSpinBox.StepEnabledFlag:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#stepEnabled

        **[override virtual protected] QAbstractSpinBox::StepEnabled
        QDateTimeEdit::stepEnabled() const**

        Reimplements: **QAbstractSpinBox::stepEnabled() const** .
        """
        ...

    def textFromDateTime(
        self, dt: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> str:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#textFromDateTime

        **[virtual protected] QString QDateTimeEdit::textFromDateTime(const
        QDateTime & dateTime ) const**

        This virtual function is used by the date time edit whenever it needs to
        display **dateTime**.

        If you reimplement this, you may also need to reimplement **validate**
        ().

        **See also** **dateTimeFromText** () and **validate** ().
        """
        ...

    def dateTimeFromText(self, text: str) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#dateTimeFromText

        **[virtual protected] QDateTime QDateTimeEdit::dateTimeFromText(const
        QString & text ) const**

        Returns an appropriate datetime for the given **text**.

        This virtual function is used by the datetime edit whenever it needs to
        interpret text entered by the user as a value.

        **See also** **textFromDateTime** () and **validate** ().
        """
        ...

    def fixup(self, input: str) -> str:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#fixup

        **[override virtual protected] void QDateTimeEdit::fixup(QString & input
        ) const**

        Reimplements: **QAbstractSpinBox::fixup(QString &input) const** .
        """
        ...

    def validate(
        self, input: str, pos: int
    ) -> typing.Tuple[QtGui.QValidator.State, str, int]:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#validate

        **[override virtual protected] QValidator::State
        QDateTimeEdit::validate(QString & text , int & pos ) const**

        Reimplements: **QAbstractSpinBox::validate(QString &input, int &pos)
        const** .
        """
        ...

    def paintEvent(self, event: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#paintEvent

        **[override virtual protected] void
        QDateTimeEdit::paintEvent(QPaintEvent * event )**

        Reimplements: **QAbstractSpinBox::paintEvent** (QPaintEvent *event).
        """
        ...

    def mousePressEvent(self, event: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#mousePressEvent

        **[override virtual protected] void
        QDateTimeEdit::mousePressEvent(QMouseEvent * event )**

        Reimplements: **QAbstractSpinBox::mousePressEvent** (QMouseEvent
        *event).
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#focusNextPrevChild

        **[override virtual protected] bool
        QDateTimeEdit::focusNextPrevChild(bool next )**

        Reimplements: **QWidget::focusNextPrevChild** (bool next).
        """
        ...

    def focusInEvent(self, e: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#focusInEvent

        **[override virtual protected] void
        QDateTimeEdit::focusInEvent(QFocusEvent * event )**

        Reimplements: **QAbstractSpinBox::focusInEvent** (QFocusEvent *event).
        """
        ...

    def wheelEvent(self, e: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#wheelEvent

        **[override virtual protected] void
        QDateTimeEdit::wheelEvent(QWheelEvent * event )**

        Reimplements: **QAbstractSpinBox::wheelEvent** (QWheelEvent *event).
        """
        ...

    def keyPressEvent(self, e: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#keyPressEvent

        **[override virtual protected] void
        QDateTimeEdit::keyPressEvent(QKeyEvent * event )**

        Reimplements: **QAbstractSpinBox::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionSpinBox") -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#initStyleOption

        **[override virtual protected] void
        QDateTimeEdit::initStyleOption(QStyleOptionSpinBox * option ) const**

        Reimplements: **QAbstractSpinBox::initStyleOption(QStyleOptionSpinBox
        *option) const** .

        Initialize **option** with the values from this QDataTimeEdit. This
        method is useful for subclasses when they need a **QStyleOptionSpinBox**
        , but don't want to fill in all the information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def setTime(self, time: typing.Union[QtCore.QTime, datetime.time]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#time

        **QTime QDateTimeEdit::time() const**

        Returns the time of the date time edit.

        **Note:** Getter function for property time.

        **See also** **setTime** ().
        """
        ...

    def setDate(self, date: typing.Union[QtCore.QDate, datetime.date]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#date

        **QDate QDateTimeEdit::date() const**

        Returns the date of the date time edit.

        **Note:** Getter function for property date.

        **See also** **setDate** ().
        """
        ...

    def setDateTime(
        self, dateTime: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#dateTime-prop

        **dateTime : QDateTime**

        This property holds the **QDateTime**  that is set in the
        **QDateTimeEdit** .

        When setting this property, the new **QDateTime**  is converted to the
        timespec of the **QDateTimeEdit** , which thus remains unchanged.

        By default, this property is set to the start of 2000 CE. It can only be
        set to a valid **QDateTime**  value. If any operation causes this
        property to have an invalid date-time as value, it is reset to the value
        of the **minimumDateTime**  property.

        If the **QDateTimeEdit**  has no date fields, setting this property sets
        the widget's date-range to start and end on the date of the new value of
        this property.

        **Access functions:**

        QDateTime **dateTime** () const
        void **setDateTime** (const QDateTime
        & **dateTime** )

        **Notifier signal:**

        void ****dateTimeChanged** ** (const QDateTime & **datetime** )

        **See also** **date** , **time** , **minimumDateTime** , and
        **maximumDateTime** .
        """
        ...

    def sectionCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#sectionCount-prop

        **[read-only] sectionCount : const int**

        This property holds the number of sections displayed. If the format is
        'yyyy/yy/yyyy', sectionCount returns 3

        **Access functions:**

        int **sectionCount** () const
        """
        ...

    def setCurrentSectionIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#currentSectionIndex-prop

        **currentSectionIndex : int**

        This property holds the current section index of the spinbox.

        If the format is 'yyyy/MM/dd', the displayText is '2001/05/21', and the
        cursorPosition is 5, currentSectionIndex returns 1. If the
        cursorPosition is 3, currentSectionIndex is 0, and so on.

        **Access functions:**

        int **currentSectionIndex** () const
        void **setCurrentSectionIndex**
        (int **index** )

        **See also** **setCurrentSection** () and **currentSection** ().
        """
        ...

    def currentSectionIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#currentSectionIndex-prop

        **currentSectionIndex : int**

        This property holds the current section index of the spinbox.

        If the format is 'yyyy/MM/dd', the displayText is '2001/05/21', and the
        cursorPosition is 5, currentSectionIndex returns 1. If the
        cursorPosition is 3, currentSectionIndex is 0, and so on.

        **Access functions:**

        int **currentSectionIndex** () const
        void **setCurrentSectionIndex**
        (int **index** )

        **See also** **setCurrentSection** () and **currentSection** ().
        """
        ...

    def sectionAt(self, index: int) -> "QDateTimeEdit.Section":
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#sectionAt

        **QDateTimeEdit::Section QDateTimeEdit::sectionAt(int index ) const**

        Returns the Section at **index**.

        If the format is 'yyyy/MM/dd', sectionAt(0) returns **YearSection** ,
        sectionAt(1) returns **MonthSection** , and sectionAt(2) returns
        **YearSection** ,
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#event

        **[override virtual] bool QDateTimeEdit::event(QEvent * event )**

        Reimplements: **QAbstractSpinBox::event** (QEvent *event).
        """
        ...

    def stepBy(self, steps: int) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#stepBy

        **[override virtual] void QDateTimeEdit::stepBy(int steps )**

        Reimplements: **QAbstractSpinBox::stepBy** (int steps).
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#clear

        **[override virtual] void QDateTimeEdit::clear()**

        Reimplements: **QAbstractSpinBox::clear** ().
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#sizeHint

        **[override virtual] QSize QDateTimeEdit::sizeHint() const**

        Reimplements: **QAbstractSpinBox::sizeHint() const** .
        """
        ...

    def setSelectedSection(self, section: "QDateTimeEdit.Section") -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#setSelectedSection

        **void QDateTimeEdit::setSelectedSection(QDateTimeEdit::Section section
        )**

        Selects **section**. If **section** doesn't exist in the currently
        displayed sections, this function does nothing. If **section** is
        **NoSection** , this function will unselect all text in the editor.
        Otherwise, this function will move the cursor and the current section to
        the selected section.

        **See also** **currentSection** ().
        """
        ...

    def setCalendarPopup(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#calendarPopup-prop

        **calendarPopup : bool**

        This property holds the current calendar pop-up show mode.

        The calendar pop-up will be shown upon clicking the arrow button. This
        property is valid only if there is a valid date display format.

        **Access functions:**

        bool **calendarPopup** () const
        void **setCalendarPopup** (bool
        **enable** )

        **See also** **setDisplayFormat** ().
        """
        ...

    def calendarPopup(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#calendarPopup-prop

        **calendarPopup : bool**

        This property holds the current calendar pop-up show mode.

        The calendar pop-up will be shown upon clicking the arrow button. This
        property is valid only if there is a valid date display format.

        **Access functions:**

        bool **calendarPopup** () const
        void **setCalendarPopup** (bool
        **enable** )

        **See also** **setDisplayFormat** ().
        """
        ...

    def setDisplayFormat(self, format: str) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#displayFormat-prop

        **displayFormat : QString**

        This property holds the format used to display the time/date of the date
        time edit.

        This format is described in **QDateTime::toString** () and
        **QDateTime::fromString** ()

        Example format strings (assuming that the date is 2nd of July 1969):

        FormatResult
        dd.MM.yyyy02.07.1969
        MMM d yyJul 2 69
        MMMM d yyJuly 2
        69

        Note that if you specify a two digit year, it will be interpreted to be
        in the century in which the date time edit was initialized. The default
        century is the 21st (2000-2099).

        If you specify an invalid format the format will not be set.

        **Access functions:**

        QString **displayFormat** () const
        void **setDisplayFormat** (const
        QString & **format** )

        **See also** **QDateTime::toString** () and **displayedSections** ().
        """
        ...

    def displayFormat(self) -> str:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#displayFormat-prop

        **displayFormat : QString**

        This property holds the format used to display the time/date of the date
        time edit.

        This format is described in **QDateTime::toString** () and
        **QDateTime::fromString** ()

        Example format strings (assuming that the date is 2nd of July 1969):

        FormatResult
        dd.MM.yyyy02.07.1969
        MMM d yyJul 2 69
        MMMM d yyJuly 2
        69

        Note that if you specify a two digit year, it will be interpreted to be
        in the century in which the date time edit was initialized. The default
        century is the 21st (2000-2099).

        If you specify an invalid format the format will not be set.

        **Access functions:**

        QString **displayFormat** () const
        void **setDisplayFormat** (const
        QString & **format** )

        **See also** **QDateTime::toString** () and **displayedSections** ().
        """
        ...

    def sectionText(self, s: "QDateTimeEdit.Section") -> str:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#sectionText

        **QString QDateTimeEdit::sectionText(QDateTimeEdit::Section section )
        const**

        Returns the text from the given **section**.

        **See also** **currentSection** ().
        """
        ...

    def setCurrentSection(self, section: "QDateTimeEdit.Section") -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#currentSection-prop

        **currentSection : Section**

        This property holds the current section of the spinbox.

        **Access functions:**

        QDateTimeEdit::Section **currentSection** () const
        void
        **setCurrentSection** (QDateTimeEdit::Section **section** )
        """
        ...

    def currentSection(self) -> "QDateTimeEdit.Section":
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#currentSection-prop

        **currentSection : Section**

        This property holds the current section of the spinbox.

        **Access functions:**

        QDateTimeEdit::Section **currentSection** () const
        void
        **setCurrentSection** (QDateTimeEdit::Section **section** )
        """
        ...

    def displayedSections(self) -> "QDateTimeEdit.Section":
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#displayedSections-prop

        **[read-only] displayedSections : const Sections**

        This property holds the currently displayed fields of the date time
        edit.

        Returns a bit set of the displayed sections for this format.

        **Access functions:**

        QDateTimeEdit::Sections **displayedSections** () const

        **See also** **setDisplayFormat** () and **displayFormat** ().
        """
        ...

    def setTimeRange(
        self,
        min: typing.Union[QtCore.QTime, datetime.time],
        max: typing.Union[QtCore.QTime, datetime.time],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#setTimeRange

        **void QDateTimeEdit::setTimeRange(QTime min , QTime max )**

        Set the range of allowed times for the date time edit.

        This convenience function sets the **minimumTime**  and **maximumTime**
        properties.

        Note that these only constrain the date time edit's value on,
        respectively, the **minimumDate**  and **maximumDate** . When these date
        properties do not coincide, times after **max** are allowed on dates
        before **maximumDate**  and times before **min** are allowed on dates
        after **minimumDate** .

        setTimeRange(min, max);

        is analogous to:

        setMinimumTime(min);
            setMaximumTime(max);

        If either **min** or **max** is invalid, this function does nothing.
        This function preserves the **minimumDate**  and **maximumDate**
        properties. If those properties coincide and **max** is less than
        **min** , **min** is used as **max**.

        If the range is narrower then a time interval whose end it spans, for
        example the interval from ten to an hour to ten past the same hour,
        users can only edit the time to one in the later part of the range if
        keyboard-tracking is disabled.

        **See also** **minimumTime** , **maximumTime** , **setDateTimeRange**
        (), **QTime::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def clearMaximumTime(self) -> None:
        ...

    def setMaximumTime(self, max: typing.Union[QtCore.QTime, datetime.time]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#maximumTime-prop

        **maximumTime : QTime**

        This property holds the maximum time of the date time edit.

        Changing this property updates the time of the **maximumDateTime**
        property while preserving the **minimumDate**  and **maximumDate**
        properties. If those date properties coincide, when setting this
        property, the **minimumTime**  property is adjusted, if necessary, to
        ensure that the range remains valid. Otherwise, changing this property
        preserves the **minimumDateTime**  property.

        This property can be set to any valid **QTime**  value. By default, this
        property contains a time of 23:59:59 and 999 milliseconds. This default
        can be restored with clearMaximumTime().

        **Access functions:**

        QTime **maximumTime** () const
        void **setMaximumTime** (QTime **max**
        )
        void **clearMaximumTime** ()

        **See also** **minimumTime** , **maximumDate** , **maximumDateTime** ,
        **setTimeRange** (), **QTime::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def maximumTime(self) -> QtCore.QTime:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#maximumTime-prop

        **maximumTime : QTime**

        This property holds the maximum time of the date time edit.

        Changing this property updates the time of the **maximumDateTime**
        property while preserving the **minimumDate**  and **maximumDate**
        properties. If those date properties coincide, when setting this
        property, the **minimumTime**  property is adjusted, if necessary, to
        ensure that the range remains valid. Otherwise, changing this property
        preserves the **minimumDateTime**  property.

        This property can be set to any valid **QTime**  value. By default, this
        property contains a time of 23:59:59 and 999 milliseconds. This default
        can be restored with clearMaximumTime().

        **Access functions:**

        QTime **maximumTime** () const
        void **setMaximumTime** (QTime **max**
        )
        void **clearMaximumTime** ()

        **See also** **minimumTime** , **maximumDate** , **maximumDateTime** ,
        **setTimeRange** (), **QTime::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def clearMinimumTime(self) -> None:
        ...

    def setMinimumTime(self, min: typing.Union[QtCore.QTime, datetime.time]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#minimumTime-prop

        **minimumTime : QTime**

        This property holds the minimum time of the date time edit.

        Changing this property updates the time of the **minimumDateTime**
        property while preserving the **minimumDate**  and **maximumDate**
        properties. If those date properties coincide, when setting this
        property, the **maximumTime**  property is adjusted, if necessary, to
        ensure that the range remains valid. Otherwise, changing this property
        preserves the **maximumDateTime**  property.

        This property can be set to any valid **QTime**  value. By default, this
        property contains a time of 00:00:00 and 0 milliseconds. This default
        can be restored with clearMinimumTime().

        **Access functions:**

        QTime **minimumTime** () const
        void **setMinimumTime** (QTime **min**
        )
        void **clearMinimumTime** ()

        **See also** **maximumTime** , **minimumDate** , **minimumDateTime** ,
        **setTimeRange** (), **QTime::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def minimumTime(self) -> QtCore.QTime:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#minimumTime-prop

        **minimumTime : QTime**

        This property holds the minimum time of the date time edit.

        Changing this property updates the time of the **minimumDateTime**
        property while preserving the **minimumDate**  and **maximumDate**
        properties. If those date properties coincide, when setting this
        property, the **maximumTime**  property is adjusted, if necessary, to
        ensure that the range remains valid. Otherwise, changing this property
        preserves the **maximumDateTime**  property.

        This property can be set to any valid **QTime**  value. By default, this
        property contains a time of 00:00:00 and 0 milliseconds. This default
        can be restored with clearMinimumTime().

        **Access functions:**

        QTime **minimumTime** () const
        void **setMinimumTime** (QTime **min**
        )
        void **clearMinimumTime** ()

        **See also** **maximumTime** , **minimumDate** , **minimumDateTime** ,
        **setTimeRange** (), **QTime::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def setDateRange(
        self,
        min: typing.Union[QtCore.QDate, datetime.date],
        max: typing.Union[QtCore.QDate, datetime.date],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#setDateRange

        **void QDateTimeEdit::setDateRange(QDate min , QDate max )**

        Set the range of allowed dates for the date time edit.

        This convenience function sets the **minimumDate**  and **maximumDate**
        properties.

        setDateRange(min, max);

        is analogous to:

        setMinimumDate(min);
            setMaximumDate(max);

        If either **min** or **max** is invalid, this function does nothing.
        This function preserves the **minimumTime**  property. If **max** is
        less than **min** , the new **maximumDateTime**  property shall be the
        new **minimumDateTime**  property. If **max** is equal to **min** and
        the **maximumTime**  property was less then the **minimumTime**
        property, the **maximumTime**  property is set to the **minimumTime**
        property. Otherwise, this preserves the **maximumTime**  property.

        If the range is narrower then a time interval whose end it spans, for
        example a week that spans the end of a month, users can only edit the
        date to one in the later part of the range if keyboard-tracking is
        disabled.

        **See also** **minimumDate** , **maximumDate** , **setDateTimeRange**
        (), **QDate::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def clearMaximumDate(self) -> None:
        ...

    def setMaximumDate(self, max: typing.Union[QtCore.QDate, datetime.date]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#maximumDate-prop

        **maximumDate : QDate**

        This property holds the maximum date of the date time edit.

        Changing this property updates the date of the **maximumDateTime**
        property while preserving the **maximumTime**  property. When setting
        this property, the **minimumDate**  is adjusted, if necessary, to ensure
        that the range remains valid. When this happens, the **minimumTime**
        property is also adjusted if it is greater than the **maximumTime**
        property. Otherwise, changes to this property preserve the
        **minimumDateTime**  property.

        This property can only be set to a valid **QDate**  object describing a
        date on which the current **maximumTime**  property makes a valid
        **QDateTime**  object. The latest date that setMaximumDate() accepts is
        the end of 9999 CE. This is the default for this property. This default
        can be restored with **clearMaximumDateTime** ().

        **Access functions:**

        QDate **maximumDate** () const
        void **setMaximumDate** (QDate **max**
        )
        void **clearMaximumDate** ()

        **See also** **minimumDate** , **maximumTime** , **maximumDateTime** ,
        **setDateRange** (), **QDate::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def maximumDate(self) -> QtCore.QDate:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#maximumDate-prop

        **maximumDate : QDate**

        This property holds the maximum date of the date time edit.

        Changing this property updates the date of the **maximumDateTime**
        property while preserving the **maximumTime**  property. When setting
        this property, the **minimumDate**  is adjusted, if necessary, to ensure
        that the range remains valid. When this happens, the **minimumTime**
        property is also adjusted if it is greater than the **maximumTime**
        property. Otherwise, changes to this property preserve the
        **minimumDateTime**  property.

        This property can only be set to a valid **QDate**  object describing a
        date on which the current **maximumTime**  property makes a valid
        **QDateTime**  object. The latest date that setMaximumDate() accepts is
        the end of 9999 CE. This is the default for this property. This default
        can be restored with **clearMaximumDateTime** ().

        **Access functions:**

        QDate **maximumDate** () const
        void **setMaximumDate** (QDate **max**
        )
        void **clearMaximumDate** ()

        **See also** **minimumDate** , **maximumTime** , **maximumDateTime** ,
        **setDateRange** (), **QDate::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def clearMinimumDate(self) -> None:
        ...

    def setMinimumDate(self, min: typing.Union[QtCore.QDate, datetime.date]) -> None:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#minimumDate-prop

        **minimumDate : QDate**

        This property holds the minimum date of the date time edit.

        Changing this property updates the date of the **minimumDateTime**
        property while preserving the **minimumTime**  property. When setting
        this property, the **maximumDate**  is adjusted, if necessary, to ensure
        that the range remains valid. When this happens, the **maximumTime**
        property is also adjusted if it is less than the **minimumTime**
        property. Otherwise, changes to this property preserve the
        **maximumDateTime**  property.

        This property can only be set to a valid **QDate**  object describing a
        date on which the current **minimumTime**  property makes a valid
        **QDateTime**  object. The earliest date that setMinimumDate() accepts
        is the start of 100 CE. The default for this property is September 14,
        1752 CE. This default can be restored with **clearMinimumDateTime** ().

        **Access functions:**

        QDate **minimumDate** () const
        void **setMinimumDate** (QDate **min**
        )
        void **clearMinimumDate** ()

        **See also** **maximumDate** , **minimumTime** , **minimumDateTime** ,
        **setDateRange** (), **QDate::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def minimumDate(self) -> QtCore.QDate:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#minimumDate-prop

        **minimumDate : QDate**

        This property holds the minimum date of the date time edit.

        Changing this property updates the date of the **minimumDateTime**
        property while preserving the **minimumTime**  property. When setting
        this property, the **maximumDate**  is adjusted, if necessary, to ensure
        that the range remains valid. When this happens, the **maximumTime**
        property is also adjusted if it is less than the **minimumTime**
        property. Otherwise, changes to this property preserve the
        **maximumDateTime**  property.

        This property can only be set to a valid **QDate**  object describing a
        date on which the current **minimumTime**  property makes a valid
        **QDateTime**  object. The earliest date that setMinimumDate() accepts
        is the start of 100 CE. The default for this property is September 14,
        1752 CE. This default can be restored with **clearMinimumDateTime** ().

        **Access functions:**

        QDate **minimumDate** () const
        void **setMinimumDate** (QDate **min**
        )
        void **clearMinimumDate** ()

        **See also** **maximumDate** , **minimumTime** , **minimumDateTime** ,
        **setDateRange** (), **QDate::isValid** (), and **Keyboard Tracking** .
        """
        ...

    def time(self) -> QtCore.QTime:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#time-prop

        **time : QTime**

        This property holds the **QTime**  that is set in the widget.

        By default, this property contains a time of 00:00:00 and 0
        milliseconds.

        **Access functions:**

        QTime ****time** ** () const
        void **setTime** (QTime **time** )

        **Notifier signal:**

        void ****timeChanged** ** (QTime **time** )

        **See also** **date**  and **dateTime** .
        """
        ...

    def date(self) -> QtCore.QDate:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#date-prop

        **date : QDate**

        This property holds the **QDate**  that is set in the widget.

        By default, this property contains a date that refers to January 1,
        2000.

        **Access functions:**

        QDate ****date** ** () const
        void **setDate** (QDate **date** )

        **Notifier signal:**

        void ****dateChanged** ** (QDate **date** )

        **See also** **time**  and **dateTime** .
        """
        ...

    def dateTime(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#dateTime-prop

        **dateTime : QDateTime**

        This property holds the **QDateTime**  that is set in the
        **QDateTimeEdit** .

        When setting this property, the new **QDateTime**  is converted to the
        timespec of the **QDateTimeEdit** , which thus remains unchanged.

        By default, this property is set to the start of 2000 CE. It can only be
        set to a valid **QDateTime**  value. If any operation causes this
        property to have an invalid date-time as value, it is reset to the value
        of the **minimumDateTime**  property.

        If the **QDateTimeEdit**  has no date fields, setting this property sets
        the widget's date-range to start and end on the date of the new value of
        this property.

        **Access functions:**

        QDateTime **dateTime** () const
        void **setDateTime** (const QDateTime
        & **dateTime** )

        **Notifier signal:**

        void ****dateTimeChanged** ** (const QDateTime & **datetime** )

        **See also** **date** , **time** , **minimumDateTime** , and
        **maximumDateTime** .
        """
        ...

    @property
    def dateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#dateChanged

        **[signal] void QDateTimeEdit::dateChanged(QDate date )**

        This signal is emitted whenever the date is changed. The new date is
        passed in **date**.

        **Note:** Notifier signal for property **date** .

        **See also** **Keyboard Tracking** .
        """
        ...

    @property
    def dateTimeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#dateTimeChanged

        **[signal] void QDateTimeEdit::dateTimeChanged(const QDateTime &
        datetime )**

        This signal is emitted whenever the date or time is changed. The new
        date and time is passed in **datetime**.

        **Note:** Notifier signal for property **dateTime** .

        **See also** **Keyboard Tracking** .
        """
        ...

    @property
    def timeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdatetimeedit.html#timeChanged

        **[signal] void QDateTimeEdit::timeChanged(QTime time )**

        This signal is emitted whenever the time is changed. The new time is
        passed in **time**.

        **Note:** Notifier signal for property **time** .

        **See also** **Keyboard Tracking** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsLinearLayout(QGraphicsLayout):
    """
    https://doc.qt.io/qt-6/qgraphicslinearlayout.html

    **Detailed Description**

    The default orientation for a linear layout is **Qt::Horizontal** . You can
    choose a vertical orientation either by calling **setOrientation** (), or by
    passing **Qt::Vertical**  to QGraphicsLinearLayout's constructor.

    The most common way to use QGraphicsLinearLayout is to construct an object
    on the heap with no parent, add widgets and layouts by calling **addItem**
    (), and finally assign the layout to a widget by calling
    **QGraphicsWidget::setLayout** ().

    **QGraphicsScene**  scene;
        **QGraphicsWidget**  *textEdit =
    scene.addWidget(new **QTextEdit** );
        **QGraphicsWidget**  *pushButton =
    scene.addWidget(new **QPushButton** );

        **QGraphicsLinearLayout**
    *layout = new **QGraphicsLinearLayout** ;
        layout->addItem(textEdit);
    layout->addItem(pushButton);

        **QGraphicsWidget**  *form = new
    **QGraphicsWidget** ;
        form->setLayout(layout);
        scene.addItem(form);

    You can add widgets, layouts, stretches (**addStretch** (),
    **insertStretch** () or **setStretchFactor** ()), and spacings
    (**setItemSpacing** ()) to a linear layout. The layout takes ownership of
    the items. In some cases when the layout item also inherits from
    **QGraphicsItem**  (such as **QGraphicsWidget** ) there will be a ambiguity
    in ownership because the layout item belongs to two ownership hierarchies.
    See the documentation of **QGraphicsLayoutItem::setOwnedByLayout** () how to
    handle this. You can access each item in the layout by calling **count** ()
    and **itemAt** (). Calling **removeAt** () or **removeItem** () will remove
    an item from the layout, without destroying it.

    **Size Hints and Size Policies in QGraphicsLinearLayout**

    QGraphicsLinearLayout respects each item's size hints and size policies, and
    when the layout contains more space than the items can fill, each item is
    arranged according to the layout's alignment for that item. You can set an
    alignment for each item by calling **setAlignment** (), and check the
    alignment for any item by calling **alignment** (). By default, items are
    aligned to the top left.

    **Spacing within QGraphicsLinearLayout**

    Between the items, the layout distributes some space. The actual amount of
    space depends on the managed widget's current style, but the common spacing
    is 4. You can also set your own spacing by calling **setSpacing** (), and
    get the current spacing value by calling **spacing** (). If you want to
    configure individual spacing for your items, you can call **setItemSpacing**
    ().

    **Stretch Factor in QGraphicsLinearLayout**

    You can assign a stretch factor to each item to control how much space it
    will get compared to the other items. By default, two identical widgets
    arranged in a linear layout will have the same size, but if the first widget
    has a stretch factor of 1 and the second widget has a stretch factor of 2,
    the first widget will get 1/3 of the available space, and the second will
    get 2/3.

    QGraphicsLinearLayout calculates the distribution of sizes by adding up the
    stretch factors of all items, and then dividing the available space
    accordingly. The default stretch factor is 0 for all items; a factor of 0
    means the item does not have any defined stretch factor; effectively this is
    the same as setting the stretch factor to 1. The stretch factor only applies
    to the available space in the lengthwise direction of the layout (following
    its orientation). If you want to control both the item's horizontal and
    vertical stretch, you can use **QGraphicsGridLayout**  instead.

    **QGraphicsLinearLayout Compared to Other Layouts**

    QGraphicsLinearLayout is very similar to **QVBoxLayout**  and
    **QHBoxLayout** , but in contrast to these classes, it is used to manage
    **QGraphicsWidget**  and **QGraphicsLayout**  instead of **QWidget**  and
    **QLayout** .

    **See also** **QGraphicsGridLayout**  and **QGraphicsWidget** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QGraphicsLayoutItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#QGraphicsLinearLayout

        **QGraphicsLinearLayout::QGraphicsLinearLayout(QGraphicsLayoutItem *
        parent = nullptr)**

        Constructs a QGraphicsLinearLayout instance using **Qt::Horizontal**
        orientation. **parent** is passed to **QGraphicsLayout** 's constructor.
        """
        ...

    @typing.overload
    def __init__(
        self,
        orientation: QtCore.Qt.Orientation,
        parent: typing.Optional[QGraphicsLayoutItem] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#QGraphicsLinearLayout-
        1

        **QGraphicsLinearLayout::QGraphicsLinearLayout(Qt::Orientation
        orientation , QGraphicsLayoutItem * parent = nullptr)**

        Constructs a QGraphicsLinearLayout instance. You can pass the
        **orientation** for the layout, either horizontal or vertical, and
        **parent** is passed to **QGraphicsLayout** 's constructor.
        """
        ...

    def sizeHint(
        self, which: QtCore.Qt.SizeHint, constraint: QtCore.QSizeF = ...
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#sizeHint

        **[override virtual] QSizeF QGraphicsLinearLayout::sizeHint(Qt::SizeHint
        which , const QSizeF & constraint = QSizeF()) const**

        Reimplements: **QGraphicsLayoutItem::sizeHint(Qt::SizeHint which, const
        QSizeF &constraint) const** .
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#invalidate

        **[override virtual] void QGraphicsLinearLayout::invalidate()**

        Reimplements: **QGraphicsLayout::invalidate** ().
        """
        ...

    def itemAt(self, index: int) -> QGraphicsLayoutItem:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#itemAt

        **[override virtual] QGraphicsLayoutItem
        *QGraphicsLinearLayout::itemAt(int index ) const**

        Reimplements: **QGraphicsLayout::itemAt(int i) const** .

        When iterating from 0 and up, it will return the items in the visual
        arranged order.
        """
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#count

        **[override virtual] int QGraphicsLinearLayout::count() const**

        Reimplements: **QGraphicsLayout::count() const** .
        """
        ...

    def setGeometry(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#setGeometry

        **[override virtual] void QGraphicsLinearLayout::setGeometry(const
        QRectF & rect )**

        Reimplements: **QGraphicsLayoutItem::setGeometry** (const QRectF &rect).
        """
        ...

    def alignment(self, item: QGraphicsLayoutItem) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#alignment

        **Qt::Alignment QGraphicsLinearLayout::alignment(QGraphicsLayoutItem *
        item ) const**

        Returns the alignment for **item**. The default alignment is
        **Qt::AlignTop**  | **Qt::AlignLeft** .

        The alignment decides how the item is positioned within its assigned
        space in the case where there's more space available in the layout than
        the widgets can occupy.

        **See also** **setAlignment** ().
        """
        ...

    def setAlignment(
        self, item: QGraphicsLayoutItem, alignment: QtCore.Qt.AlignmentFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#setAlignment

        **void QGraphicsLinearLayout::setAlignment(QGraphicsLayoutItem * item ,
        Qt::Alignment alignment )**

        Sets the alignment of **item** to **alignment**. If **item** 's
        alignment changes, the layout is automatically invalidated.

        **See also** **alignment** () and **invalidate** ().
        """
        ...

    def stretchFactor(self, item: QGraphicsLayoutItem) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#stretchFactor

        **int QGraphicsLinearLayout::stretchFactor(QGraphicsLayoutItem * item )
        const**

        Returns the stretch factor for **item**. The default stretch factor is
        0, meaning that the item has no assigned stretch factor.

        **See also** **setStretchFactor** ().
        """
        ...

    def setStretchFactor(self, item: QGraphicsLayoutItem, stretch: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#setStretchFactor

        **void QGraphicsLinearLayout::setStretchFactor(QGraphicsLayoutItem *
        item , int stretch )**

        Sets the stretch factor for **item** to **stretch**. If an item's
        stretch factor changes, this function will invalidate the layout.

        Setting **stretch** to 0 removes the stretch factor from the item, and
        is effectively equivalent to setting **stretch** to 1.

        **See also** **stretchFactor** ().
        """
        ...

    def itemSpacing(self, index: int) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#itemSpacing

        **qreal QGraphicsLinearLayout::itemSpacing(int index ) const**

        Returns the spacing after item at **index**.

        **See also** **setItemSpacing** ().
        """
        ...

    def setItemSpacing(self, index: int, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#setItemSpacing

        **void QGraphicsLinearLayout::setItemSpacing(int index , qreal spacing
        )**

        Sets the spacing after item at **index** to **spacing**.

        **See also** **itemSpacing** ().
        """
        ...

    def spacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#spacing

        **qreal QGraphicsLinearLayout::spacing() const**

        Returns the layout's spacing. Spacing refers to the vertical and
        horizontal distances between items.

        **See also** **setSpacing** ().
        """
        ...

    def setSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#setSpacing

        **void QGraphicsLinearLayout::setSpacing(qreal spacing )**

        Sets the layout's spacing to **spacing**. Spacing refers to the vertical
        and horizontal distances between items.

        **See also** **spacing** (), **setItemSpacing** (), **setStretchFactor**
        (), and **QGraphicsGridLayout::setSpacing** ().
        """
        ...

    def removeAt(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#removeAt

        **[override virtual] void QGraphicsLinearLayout::removeAt(int index )**

        Reimplements: **QGraphicsLayout::removeAt** (int index).

        Removes the item at **index** without destroying it. Ownership of the
        item is transferred to the caller.

        **See also** **removeItem** () and **insertItem** ().
        """
        ...

    def removeItem(self, item: QGraphicsLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#removeItem

        **void QGraphicsLinearLayout::removeItem(QGraphicsLayoutItem * item )**

        Removes **item** from the layout without destroying it. Ownership of
        **item** is transferred to the caller.

        **See also** **removeAt** () and **insertItem** ().
        """
        ...

    def insertStretch(self, index: int, stretch: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#insertStretch

        **void QGraphicsLinearLayout::insertStretch(int index , int stretch =
        1)**

        Inserts a stretch of **stretch** at **index** , or before any item that
        is currently at **index**.

        **See also** **addStretch** (), **setStretchFactor** (),
        **setItemSpacing** (), and **insertItem** ().
        """
        ...

    def insertItem(self, index: int, item: QGraphicsLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#insertItem

        **void QGraphicsLinearLayout::insertItem(int index , QGraphicsLayoutItem
        * item )**

        Inserts **item** into the layout at **index** , or before any item that
        is currently at **index**.

        **See also** **addItem** (), **itemAt** (), **insertStretch** (), and
        **setItemSpacing** ().
        """
        ...

    def addStretch(self, stretch: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#addStretch

        **void QGraphicsLinearLayout::addStretch(int stretch = 1)**

        This convenience function is equivalent to calling **insertStretch**
        (-1, **stretch** ).
        """
        ...

    def addItem(self, item: QGraphicsLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#addItem

        **void QGraphicsLinearLayout::addItem(QGraphicsLayoutItem * item )**

        This convenience function is equivalent to calling **insertItem** (-1,
        **item** ).
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#orientation

        **Qt::Orientation QGraphicsLinearLayout::orientation() const**

        Returns the layout orientation.

        **See also** **setOrientation** ().
        """
        ...

    def setOrientation(self, orientation: QtCore.Qt.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslinearlayout.html#setOrientation

        **void QGraphicsLinearLayout::setOrientation(Qt::Orientation orientation
        )**

        Change the layout orientation to **orientation**. Changing the layout
        orientation will automatically invalidate the layout.

        **See also** **orientation** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtHelp import *


class QHelpFilterEngine(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qhelpfilterengine.html

    **Detailed Description**

    The filter engine allows the management of filters associated with a
    **QHelpEngineCore**  instance. The help engine internally creates an
    instance of the filter engine, which can be accessed by calling
    **QHelpEngineCore::filterEngine** (). Therefore, the public constructor of
    this class is disabled.

    The filters are identified by a filter name string. Filter details are
    described by the **QHelpFilterData**  class.

    The filter engine allows for adding new filters and changing the existing
    filters' data through the **setFilterData** () method. An existing filter
    can be removed through the **removeFilter** () method.

    Out of the registered filters one can be marked as the active one. The
    active filter will be used by the associated help engine for returning
    filtered results of many different functions, such as content, index, or
    search results. If no filter is marked active, the help engine returns the
    full results list available.

    The active filter is returned by **activeFilter** () and it can be changed
    by **setActiveFilter** ().

    **See also** **QHelpEngineCore** .
    """

    @typing.overload
    def indices(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#indices

        **[since 5.15] QStringList QHelpFilterEngine::indices() const**

        Returns a sorted list of available indices. The returned list contents
        depend on the active filter, and therefore only the indices registered
        for the active filter will be returned.

        This function was introduced in Qt 5.15.
        """
        ...

    @typing.overload
    def indices(self, filterName: str) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#indices-1

        **[since 5.15] QStringList QHelpFilterEngine::indices(const QString &
        filterName ) const**

        Returns a sorted list of available indices, filtered by **filterName**.
        The returned list contents depend on the passed filter, and therefore
        only the indices registered for this filter will be returned. If you
        want to get all available indices unfiltered, pass empty string as
        **filterName**.

        This function was introduced in Qt 5.15.
        """
        ...

    def availableVersions(self) -> typing.List[QtCore.QVersionNumber]:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#availableVersions

        **[since 5.15] QList<QVersionNumber>
        QHelpFilterEngine::availableVersions() const**

        Returns the list of all available versions defined in all registered
        documentation files.

        This function was introduced in Qt 5.15.
        """
        ...

    def namespacesForFilter(self, filterName: str) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#namespacesForFilter

        **QStringList QHelpFilterEngine::namespacesForFilter(const QString &
        filterName ) const**

        Returns the list of all registered documentation namespaces that match
        the filter identified by **filterName**.
        """
        ...

    def removeFilter(self, filterName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#removeFilter

        **bool QHelpFilterEngine::removeFilter(const QString & filterName )**

        Removes the filter identified by **filterName**.

        Returns `true` if removing the filter succeeded, otherwise returns
        `false`.
        """
        ...

    def setFilterData(self, filterName: str, filterData: QHelpFilterData) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#setFilterData

        **bool QHelpFilterEngine::setFilterData(const QString & filterName ,
        const QHelpFilterData & filterData )**

        Changes the existing filter details of the filter identified by
        **filterName** to **filterData**. If the filter does not exist, a new
        filter is created.

        Returns `true` if setting the filter succeeded, otherwise returns
        `false`.

        **See also** **filterData** ().
        """
        ...

    def filterData(self, filterName: str) -> QHelpFilterData:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#filterData

        **QHelpFilterData QHelpFilterEngine::filterData(const QString &
        filterName ) const**

        Returns the filter details associated with **filterName**.

        **See also** **setFilterData** ().
        """
        ...

    def availableComponents(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#availableComponents

        **QStringList QHelpFilterEngine::availableComponents() const**

        Returns the list of all available components defined in all registered
        documentation files.
        """
        ...

    def setActiveFilter(self, filterName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#setActiveFilter

        **bool QHelpFilterEngine::setActiveFilter(const QString & filterName )**

        Changes the currently active filter to **filterName**.

        Returns `true` if changing the filter succeeded, otherwise returns
        `false`.

        **See also** **activeFilter** ().
        """
        ...

    def activeFilter(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#activeFilter

        **QString QHelpFilterEngine::activeFilter() const**

        Returns the name of the currently active filter.

        **See also** **setActiveFilter** ().
        """
        ...

    def filters(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#filters

        **QStringList QHelpFilterEngine::filters() const**

        Returns the list of all filter names defined inside the filter engine.
        """
        ...

    def namespaceToVersion(self) -> typing.Dict[str, QtCore.QVersionNumber]:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#namespaceToVersion

        **QMap<QString, QVersionNumber> QHelpFilterEngine::namespaceToVersion()
        const**

        Returns the map of all the available namespaces as keys together with
        their associated versions as values.
        """
        ...

    def namespaceToComponent(self) -> typing.Dict[str, str]:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#namespaceToComponent

        **QMap<QString, QString> QHelpFilterEngine::namespaceToComponent()
        const**

        Returns the map of all the available namespaces as keys together with
        their associated components as values.
        """
        ...

    @property
    def filterActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpfilterengine.html#filterActivated

        **[signal] void QHelpFilterEngine::filterActivated(const QString &
        newFilter )**

        This signal is emitted when the active filter is set. **newFilter**
        specifies the name of the filter.

        **See also** **setActiveFilter** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QLockFile(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlockfile.html

    **Detailed Description**

    A lock file can be used to prevent multiple processes from accessing
    concurrently the same resource. For instance, a configuration file on disk,
    or a socket, a port, a region of shared memory...

    Serialization is only guaranteed if all processes that access the shared
    resource use QLockFile, with the same file path.

    QLockFile supports two use cases: to protect a resource for a short-term
    operation (e.g. verifying if a configuration file has changed before saving
    new settings), and for long-lived protection of a resource (e.g. a document
    opened by a user in an editor) for an indefinite amount of time.

    When protecting for a short-term operation, it is acceptable to call
    **lock** () and wait until any running operation finishes. When protecting a
    resource over a long time, however, the application should always call
    **setStaleLockTime** (0) and then **tryLock** () with a short timeout, in
    order to warn the user that the resource is locked.

    If the process holding the lock crashes, the lock file stays on disk and can
    prevent any other process from accessing the shared resource, ever. For this
    reason, QLockFile tries to detect such a "stale" lock file, based on the
    process ID written into the file. To cover the situation that the process ID
    got reused meanwhile, the current process name is compared to the name of
    the process that corresponds to the process ID from the lock file. If the
    process names differ, the lock file is considered stale. Additionally, the
    last modification time of the lock file (30s by default, for the use case of
    a short-lived operation) is taken into account. If the lock file is found to
    be stale, it will be deleted.

    For the use case of protecting a resource over a long time, you should
    therefore call **setStaleLockTime** (0), and when **tryLock** () returns
    **LockFailedError** , inform the user that the document is locked, possibly
    using **getLockInfo** () for more details.

    **Note:** On Windows, this class has problems detecting a stale lock if the
    machine's hostname contains characters outside the US-ASCII character set.
    """

    class LockError(enum.Enum):
        NoError: QLockFile = ...
        LockFailedError: QLockFile = ...
        PermissionError: QLockFile = ...
        UnknownError: QLockFile = ...

    def __init__(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qlockfile.html#QLockFile

        **QLockFile::QLockFile(const QString & fileName )**

        Constructs a new lock file object. The object is created in an unlocked
        state. When calling **lock** () or **tryLock** (), a lock file named
        **fileName** will be created, if it doesn't already exist.

        **See also** **lock** () and **unlock** ().
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlockfile.html#fileName

        **QString QLockFile::fileName() const**

        Returns the file name of the lock file
        """
        ...

    def error(self) -> "QLockFile.LockError":
        """
        https://doc.qt.io/qt-6/qlockfile.html#error

        **QLockFile::LockError QLockFile::error() const**

        Returns the lock file error status.

        If **tryLock** () returns `false`, this function can be called to find
        out the reason why the locking failed.
        """
        ...

    def removeStaleLockFile(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlockfile.html#removeStaleLockFile

        **bool QLockFile::removeStaleLockFile()**

        Attempts to forcefully remove an existing lock file.

        Calling this is not recommended when protecting a short-lived operation:
        **QLockFile**  already takes care of removing lock files after they are
        older than **staleLockTime** ().

        This method should only be called when protecting a resource for a long
        time, i.e. with **staleLockTime** (0), and after **tryLock** () returned
        **LockFailedError** , and the user agreed on removing the lock file.

        Returns `true` on success, false if the lock file couldn't be removed.
        This happens on Windows, when the application owning the lock is still
        running.
        """
        ...

    def getLockInfo(self) -> typing.Tuple[bool, int, str, str]:
        """
        https://doc.qt.io/qt-6/qlockfile.html#getLockInfo

        **bool QLockFile::getLockInfo(qint64 * pid , QString * hostname ,
        QString * appname ) const**

        Retrieves information about the current owner of the lock file.

        If **tryLock** () returns `false`, and **error** () returns
        **LockFailedError** , this function can be called to find out more
        information about the existing lock file:

        * the PID of the application (returned in **pid** )
          * the **hostname**
        it's running on (useful in case of networked filesystems),
          * the name
        of the application which created it (returned in **appname** ),

        Note that **tryLock** () automatically deleted the file if there is no
        running application with this PID, so **LockFailedError**  can only
        happen if there is an application with this PID (it could be unrelated
        though).

        This can be used to inform users about the existing lock file and give
        them the choice to delete it. After removing the file using
        **removeStaleLockFile** (), the application can call **tryLock** ()
        again.

        This function returns `true` if the information could be successfully
        retrieved, false if the lock file doesn't exist or doesn't contain the
        expected data. This can happen if the lock file was deleted between the
        time where **tryLock** () failed and the call to this function. Simply
        call **tryLock** () again if this happens.
        """
        ...

    def isLocked(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlockfile.html#isLocked

        **bool QLockFile::isLocked() const**

        Returns `true` if the lock was acquired by this **QLockFile**  instance,
        otherwise returns `false`.

        **See also** **lock** (), **unlock** (), and **tryLock** ().
        """
        ...

    def staleLockTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qlockfile.html#staleLockTime

        **int QLockFile::staleLockTime() const**

        Returns the time in milliseconds after which a lock file is considered
        stale.

        **See also** **setStaleLockTime** ().
        """
        ...

    def setStaleLockTime(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qlockfile.html#setStaleLockTime

        **void QLockFile::setStaleLockTime(int staleLockTime )**

        Sets **staleLockTime** to be the time in milliseconds after which a lock
        file is considered stale. The default value is 30000, i.e. 30 seconds.
        If your application typically keeps the file locked for more than 30
        seconds (for instance while saving megabytes of data for 2 minutes), you
        should set a bigger value using setStaleLockTime().

        The value of **staleLockTime** is used by **lock** () and **tryLock** ()
        in order to determine when an existing lock file is considered stale,
        i.e. left over by a crashed process. This is useful for the case where
        the PID got reused meanwhile, so one way to detect a stale lock file is
        by the fact that it has been around for a long time.

        **See also** **staleLockTime** ().
        """
        ...

    def unlock(self) -> None:
        """
        https://doc.qt.io/qt-6/qlockfile.html#unlock

        **void QLockFile::unlock()**

        Releases the lock, by deleting the lock file.

        Calling unlock() without locking the file first, does nothing.

        **See also** **lock** () and **tryLock** ().
        """
        ...

    def tryLock(self, timeout: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qlockfile.html#tryLock

        **bool QLockFile::tryLock(int timeout = 0)**

        Attempts to create the lock file. This function returns `true` if the
        lock was obtained; otherwise it returns `false`. If another process (or
        another thread) has created the lock file already, this function will
        wait for at most **timeout** milliseconds for the lock file to become
        available.

        Note: Passing a negative number as the **timeout** is equivalent to
        calling **lock** (), i.e. this function will wait forever until the lock
        file can be locked if **timeout** is negative.

        If the lock was obtained, it must be released with **unlock** () before
        another process (or thread) can successfully lock it.

        Calling this function multiple times on the same lock from the same
        thread without unlocking first is not allowed, this function will
        **always** return false when attempting to lock the file recursively.

        **See also** **lock** () and **unlock** ().
        """
        ...

    def lock(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlockfile.html#lock

        **bool QLockFile::lock()**

        Creates the lock file.

        If another process (or another thread) has created the lock file
        already, this function will block until that process (or thread)
        releases it.

        Calling this function multiple times on the same lock from the same
        thread without unlocking first is not allowed. This function will
        **dead-lock** when the file is locked recursively.

        Returns `true` if the lock was acquired, false if it could not be
        acquired due to an unrecoverable error, such as no permissions in the
        parent directory.

        **See also** **unlock** () and **tryLock** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtWidgets import *
import enum


class QTreeWidgetItemIterator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtreewidgetitemiterator.html

    **Detailed Description**

    The iterator will walk the items in a pre-order traversal order, thus
    visiting the parent node **before** it continues to the child nodes.

    For example, the following code examples each item in a tree, checking the
    text in the first column against a user-specified search string:

    **QTreeWidgetItemIterator**  it(treeWidget);
            while (*it) {
    if ((*it)->text(0) == itemText)
                    (*it)->setSelected(true);
    ++it;
            }

    It is also possible to filter out certain types of node by passing certain
    **flags**  to the constructor of QTreeWidgetItemIterator.

    **See also** **QTreeWidget** , **Model/View Programming** , and
    **QTreeWidgetItem** .
    """

    class IteratorFlag(enum.Flag):
        All: QTreeWidgetItemIterator = ...
        Hidden: QTreeWidgetItemIterator = ...
        NotHidden: QTreeWidgetItemIterator = ...
        Selected: QTreeWidgetItemIterator = ...
        Unselected: QTreeWidgetItemIterator = ...
        Selectable: QTreeWidgetItemIterator = ...
        NotSelectable: QTreeWidgetItemIterator = ...
        DragEnabled: QTreeWidgetItemIterator = ...
        DragDisabled: QTreeWidgetItemIterator = ...
        DropEnabled: QTreeWidgetItemIterator = ...
        DropDisabled: QTreeWidgetItemIterator = ...
        HasChildren: QTreeWidgetItemIterator = ...
        NoChildren: QTreeWidgetItemIterator = ...
        Checked: QTreeWidgetItemIterator = ...
        NotChecked: QTreeWidgetItemIterator = ...
        Enabled: QTreeWidgetItemIterator = ...
        Disabled: QTreeWidgetItemIterator = ...
        Editable: QTreeWidgetItemIterator = ...
        NotEditable: QTreeWidgetItemIterator = ...
        UserFlag: QTreeWidgetItemIterator = ...

    @typing.overload
    def __init__(self, it: "QTreeWidgetItemIterator") -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitemiterator.html#QTreeWidgetItemItera
        tor

        **QTreeWidgetItemIterator::QTreeWidgetItemIterator(const
        QTreeWidgetItemIterator & it )**

        Constructs an iterator for the same **QTreeWidget**  as **it**. The
        current iterator item is set to point on the current item of **it**.
        """
        ...

    @typing.overload
    def __init__(
        self, widget: QTreeWidget, flags: "QTreeWidgetItemIterator.IteratorFlag" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitemiterator.html#QTreeWidgetItemItera
        tor-1

        **QTreeWidgetItemIterator::QTreeWidgetItemIterator(QTreeWidget * widget
        , QTreeWidgetItemIterator::IteratorFlags flags = All)**

        Constructs an iterator for the given **widget** that uses the specified
        **flags** to determine which items are found during iteration. The
        iterator is set to point to the first top-level item contained in the
        widget, or the next matching item if the top-level item doesn't match
        the flags.

        **See also** **QTreeWidgetItemIterator::IteratorFlag** .
        """
        ...

    @typing.overload
    def __init__(
        self, item: QTreeWidgetItem, flags: "QTreeWidgetItemIterator.IteratorFlag" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitemiterator.html#QTreeWidgetItemItera
        tor-2

        **QTreeWidgetItemIterator::QTreeWidgetItemIterator(QTreeWidgetItem *
        item , QTreeWidgetItemIterator::IteratorFlags flags = All)**

        Constructs an iterator for the given **item** that uses the specified
        **flags** to determine which items are found during iteration. The
        iterator is set to point to **item** , or the next matching item if
        **item** doesn't match the flags.

        **See also** **QTreeWidgetItemIterator::IteratorFlag** .
        """
        ...

    def value(self) -> QTreeWidgetItem:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtNfc import *


class QNdefNfcIconRecord(QNdefRecord):
    """
    https://doc.qt.io/qt-6/qndefnfciconrecord.html

    **Detailed Description**

    This class wraps the image data into an NDEF message. It provides an NDEF
    record of type **QNdefRecord::Mime** . The **payload** () contains the raw
    image data.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfciconrecord.html#QNdefNfcIconRecord

        **QNdefNfcIconRecord::QNdefNfcIconRecord()**

        Constructs an empty NDEF record of type **QNdefRecord::Mime** .
        """
        ...

    @typing.overload
    def __init__(self, other: QNdefRecord) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfciconrecord.html#QNdefNfcIconRecord-1

        **QNdefNfcIconRecord::QNdefNfcIconRecord(const QNdefRecord & other )**

        Constructs an NDEF icon record that is a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QNdefNfcIconRecord") -> None:
        """
        https://doc.qt.io/qt-6/qndefnfciconrecord.html#QNdefNfcIconRecord

        **QNdefNfcIconRecord::QNdefNfcIconRecord()**

        Constructs an empty NDEF record of type **QNdefRecord::Mime** .
        """
        ...

    def data(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qndefnfciconrecord.html#data

        **QByteArray QNdefNfcIconRecord::data() const**

        Returns the icon data as **QByteArray** .

        **See also** **setData** ().
        """
        ...

    def setData(self, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfciconrecord.html#setData

        **void QNdefNfcIconRecord::setData(const QByteArray & data )**

        Sets the contents of the icon record to **data**.

        **See also** **data** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtDBus import *


class QDBusPendingReply(QDBusPendingCall):
    """
    https://doc.qt.io/qt-6/qdbuspendingreply.html

    **Detailed Description**

    The QDBusPendingReply is a variadic template class. The template parameters
    are the types that will be used to extract the contents of the reply's data.

    This class is similar in functionality to **QDBusReply** , but with two
    important differences:

    * **QDBusReply**  accepts exactly one return type, whereas QDBusPendingReply
    can have any number of types
      * **QDBusReply**  only works on already
    completed replies, whereas QDBusPendingReply allows one to wait for replies
    from pending calls

    Where with **QDBusReply**  you would write:

    **QDBusReply** <**QString** > reply = interface->call("RemoteMethod");
    if (reply.isValid())
            // use the returned value
    useValue(reply.value());
        else
            // call failed. Show an error
    condition.
            showError(reply.error());

    with QDBusPendingReply, the equivalent code (including the blocking wait for
    the reply) would be:

    **QDBusPendingReply** <**QString** > reply =
    iface->asyncCall("RemoteMethod");
            reply.waitForFinished();
    if (reply.isError())
                // call failed. Show an error condition.
    showErrorD(reply.error());
            else
                // use the returned
    value
                useValue(reply.value());

    For method calls that have more than one output argument, with
    **QDBusReply** , you would write:

    reply = interface->call("RemoteMethod");

    whereas with QDBusPendingReply, all of the output arguments should be
    template parameters:

    **QDBusPendingReply** <bool, **QString** > reply =
    iface->asyncCall("RemoteMethod");
            reply.waitForFinished();
    if (!reply.isError()) {
                if (reply.argumentAt<0>())
    showSuccess(reply.argumentAt<1>());
                else
    showFailure(reply.argumentAt<1>());
            }

    QDBusPendingReply objects can be associated with **QDBusPendingCallWatcher**
    objects, which emit signals when the reply arrives.

    **See also** **QDBusPendingCallWatcher**  and **QDBusReply** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#QDBusPendingReply

        **QDBusPendingReply::QDBusPendingReply()**

        Creates an empty QDBusPendingReply object. Without assigning a
        **QDBusPendingCall**  object to this reply, QDBusPendingReply cannot do
        anything. All functions return their failure values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDBusPendingReply") -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#QDBusPendingReply-1

        **QDBusPendingReply::QDBusPendingReply(const QDBusPendingReply<Types...>
        & other )**

        Creates a copy of the **other** QDBusPendingReply object. Just like
        **QDBusPendingCall**  and **QDBusPendingCallWatcher** , this
        QDBusPendingReply object will share the same pending call reference. All
        copies share the same return values.
        """
        ...

    @typing.overload
    def __init__(self, call: QDBusPendingCall) -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#QDBusPendingReply-2

        **QDBusPendingReply::QDBusPendingReply(const QDBusPendingCall & call )**

        Creates a QDBusPendingReply object that will take its contents from the
        **call** pending asynchronous call. This QDBusPendingReply object will
        share the same pending call reference as **call**.
        """
        ...

    @typing.overload
    def __init__(self, reply: QDBusMessage) -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#QDBusPendingReply-3

        **QDBusPendingReply::QDBusPendingReply(const QDBusMessage & message )**

        Creates a QDBusPendingReply object that will take its contents from the
        message **message**. In this case, this object will be already in its
        finished state and the reply's contents will be accessible.

        **See also** **isFinished** ().
        """
        ...

    def value(self, type: typing.Any = ...) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#value

        **typename Select<0>::Type QDBusPendingReply::value() const**

        Returns the first argument in this reply, cast to type `Types[0]` (the
        first template parameter of this class). This is equivalent to calling
        **argumentAt** <0>().

        This function is provided as a convenience, matching the
        **QDBusReply::value** () function.

        Note that, if the reply hasn't arrived, this function causes the calling
        thread to block until the reply is processed.

        If the reply is an error reply, this function returns a default-
        constructed `Types[0]` object, which may be indistinguishable from a
        valid value. To reliably determine whether the message was an error, use
        **isError** ().
        """
        ...

    def waitForFinished(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#waitForFinished

        **void QDBusPendingReply::waitForFinished()**

        Suspends the execution of the calling thread until the reply is received
        and processed. After this function returns, **isFinished** () should
        return true, indicating the reply's contents are ready to be processed.

        **See also** **QDBusPendingCallWatcher::waitForFinished** ().
        """
        ...

    def reply(self) -> QDBusMessage:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#reply

        **QDBusMessage QDBusPendingReply::reply() const**

        Retrieves the reply message received for the asynchronous call that was
        sent, if it has finished processing. If the pending call is not
        finished, this function returns a **QDBusMessage**  of type
        **QDBusMessage::InvalidMessage** .

        After it has finished processing, the message type will either be an
        error message or a normal method reply message.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#isValid

        **bool QDBusPendingReply::isValid() const**

        Returns `true` if the reply contains a normal reply message, false if it
        contains anything else.

        If the pending call has not finished processing, this function return
        false.
        """
        ...

    def isFinished(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#isFinished

        **bool QDBusPendingReply::isFinished() const**

        Returns `true` if the pending call has finished processing and the reply
        has been received. If this function returns `true`, the **isError** (),
        **error** () and **reply** () methods should return valid information.

        Note that this function only changes state if you call
        **waitForFinished** () or if an external D-Bus event happens, which in
        general only happens if you return to the event loop execution.

        **See also** **QDBusPendingCallWatcher::isFinished** ().
        """
        ...

    def isError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#isError

        **bool QDBusPendingReply::isError() const**

        Returns `true` if the reply contains an error message, false if it
        contains a normal method reply.

        If the pending call has not finished processing, this function also
        returns `true`.
        """
        ...

    def error(self) -> QDBusError:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#error

        **QDBusError QDBusPendingReply::error() const**

        Retrieves the error content of the reply message, if it has finished
        processing. If the reply message has not finished processing or if it
        contains a normal reply message (non-error), this function returns an
        invalid **QDBusError** .
        """
        ...

    def argumentAt(self, index: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qdbuspendingreply.html#argumentAt-1

        **QVariant QDBusPendingReply::argumentAt(int index ) const**

        Returns the argument at position **index** in the reply's contents. If
        the reply doesn't have that many elements, this function's return value
        is undefined (will probably cause an assertion failure), so it is
        important to verify that the processing is finished and the reply is
        valid.

        If the reply does not contain an argument at position **index** or if
        the reply was an error, this function returns an invalid **QVariant** .
        Since D-Bus messages can never contain invalid QVariants, this return
        can be used to detect an error condition.
        """
        ...
